@@ -1,4 +1,4 @@
-/* (C) Marcin Kwadrans <quar@vitea.pl> */
+/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 /*! \file board.h 
 	\brief Zarządzanie planszą
@@ -14,6 +14,7 @@
 
 class LWRow;
 class LWBoardSet;
+class LWWizard;
 
 /*! \class LWBoard
 	\brief Zarządzanie planszą
@@ -34,6 +35,7 @@ LWType type;
 guint piecesize;
 gboolean enable_grid;
 LWBoardSet *boardset;
+LWWizard *wizard;
 void init (LWType a_type);
 void buildResizeBar ();
 public:
@@ -59,6 +61,7 @@ gboolean isGridEnabled ();
 void clear ();
 void markPiece (LWPiece *piece);
 void unmarkPiece ();
+LWWizard *getWizard ();
 GtkWidget *getWidget ();
 LWType getType();
 gboolean isRowDummy (LWRow *row);
