@@ -1,4 +1,4 @@
-/* (C) Marcin Kwadrans <quar@vitea.pl> */
+/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 /*! \file environment.h 
 	\brief Zarządzanie całym środowiskiem
@@ -21,7 +21,7 @@
 	bibliotekę przez metodę init w tej klasie.
 */
 
-typedef enum LWDesign {
+enum LWDesign {
 LW_DESIGN_WORLD=0,
 LW_DESIGN_PROGRAM=1,
 LW_DESIGN_MIXED=2
@@ -44,7 +44,7 @@ static gboolean enabled_grid;
 static xmlNode *initializeXMLTree (xmlDocPtr &doc);	
 static void clear();
 public:
-static void init();
+static void init(GData *the_symbols);
 static void uninit ();
 static LWPixmapSet *getPixmapSet ();
 static xmlNode *getWizardXML ();
@@ -55,7 +55,7 @@ static LWProject *getProject ();
 static void registerProgram (LWProgram *a_program);
 static void unregisterProgram ();
 static LWProgram *getProgram ();
-static gchar *buildPixmapFilename (gchar *file);
+static gchar *buildPixmapFilename (const gchar *file);
 static GData *getSymbols ();
 static void enableGrid (gboolean enable);
 static GtkWidget *getWidget ();
