@@ -1,4 +1,4 @@
-/* (C) Marcin Kwadrans <quar@vitea.pl> */
+/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 /*! \file piece.h 
 	\brief Obsługa klocków
@@ -27,7 +27,6 @@ LWSymbol *symbol;
 GtkWidget *widget;
 GtkWidget *image;
 gboolean inverted_grounds;
-gboolean is_enter;
 void init (LWRow *row);
 void attach (LWRow *row);
 public:
@@ -49,7 +48,7 @@ void updateImage ();
 void enableInvertedGrounds (gboolean inverted);
 void clear();
 void copy (LWPiece *piece);
-gboolean isEnter ();
+gboolean ifDNDWillMoveWizard();
 GtkWidget *getWidget ();
 };
 
