@@ -1,4 +1,4 @@
-/* (C) Marcin Kwadrans <quar@vitea.pl> */
+/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 /*! \file project.h 
 	\brief Zarządzanie projektami
@@ -26,8 +26,8 @@ void setFileName (const gchar *a_file_name);
 public:
 LWProject ();
 ~LWProject ();
-void load (const gchar *file_name);
-void save (const gchar *file_name);
+gboolean load (const gchar *file_name);
+gboolean save (const gchar *file_name);
 gchar *getFileName ();
 LWBoard *getWorld ();
 LWBoard *getProgram ();
