@@ -1,4 +1,4 @@
-/* (C) Marcin Kwadrans <quar@vitea.pl> */
+/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 /*! \file row.h
 	\brief Zarządzanie wierszem
@@ -23,6 +23,7 @@ class LWRow {
 private:
 GSList *list_piece;
 LWPiece *dummy_piece;
+LWPiece *remark_piece;
 GtkWidget *widget;
 LWBoard *board;
 void init (LWBoard *a_board);
@@ -45,8 +46,10 @@ guint getWidth ();
 void updatePieceSize ();
 void updateGrid ();
 void clear ();
+void setAsRemark(LWPiece *a_piece);
+void clearRemark();
 GtkWidget *getWidget ();
-gboolean isPieceDummy (LWPiece *row);
+gboolean isPieceDummy (LWPiece *piece);
 };
 
 #include "board.h"
