@@ -1,4 +1,4 @@
-/* (C) Marcin Kwadrans <quar@vitea.pl> */
+/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 /*! \file symbol.h
 	\brief Zarządzanie symbolami
@@ -7,6 +7,8 @@
 #ifndef __LW_SYMBOL_H
 #define __LW_SYMBOL_H
 
+class LWPiece;
+
 /*! \class LWSymbol
 	\brief Zarządzanie symbol
 
@@ -19,7 +21,7 @@ private:
 guint id;
 GQuark quark;
 static GData *datalist_symbols;
-static GSList *list_symbols;
+static GData *datalist_symbols_with_id;
 public:
 LWSymbol();
 virtual ~LWSymbol();
@@ -30,10 +32,12 @@ virtual gchar *getHint () = 0;
 virtual const gchar *getName () = 0;
 virtual gboolean isCommand ();
 virtual gboolean isValue ();
+virtual void onDndCopy (LWPiece *sourcepiece, LWPiece *destpiece);
+virtual void onDndMove (LWPiece *sourcepiece, LWPiece *destpiece);
+virtual void onAttach (LWPiece *piece);
 static LWSymbol *factory (const gchar *name);
 static LWSymbol *factoryId (const gchar *name, guint id);
 static void destroyAll ();
-
 };
 
 #endif
