@@ -1,7 +1,7 @@
-/* (C) Marcin Kwadrans <quar@vitea.pl> */
+/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 /*! \file value.h
-	\brief Zarządzanie wartościami
+	\brief Value managing
 */
 
 #ifndef __LW_VALUE_H
@@ -10,9 +10,9 @@
 #include "pixmap.h"
 
 /*! \class LWValue
-	\brief Zarządzanie wartościami
+	\brief Value managing
 
-	Klasa reprezentująca wartości argumentów poleceń
+	Class represents values of arguments of commands	
 */
 
 class LWValue {
@@ -23,19 +23,23 @@ LWPixmap *pixmap;
 GSList *list;
 };
 void convertToList();
-virtual gboolean isSpecial();
 public:
 LWValue ();
 LWValue (LWPixmap *pixmap);
 LWValue (gint ivalue);
 LWValue (const LWValue *value);
 virtual ~LWValue ();
+virtual gboolean isSpecial();
 virtual void clear ();
 virtual void append (LWPixmap *pixmap);
 virtual void concat (LWValue *value);
+virtual gboolean isInt ();
 virtual gint toInt ();
+virtual gboolean checkRange ();
+virtual gint compare (LWValue *v);
 virtual gboolean canBeIndexed ();
 virtual LWValue *getIndex (guint n);
+virtual void deleteIndex (guint n);
 virtual GSList *getListPixmap ();
 virtual LWPixmap *getPixmap ();
 virtual void set (LWValue *value);
