@@ -1,4 +1,4 @@
-/* (C) Marcin Kwadrans <quar@vitea.pl> */
+/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 /*! \file wizard.h
 	\brief Zarządzanie czarodziejem
@@ -9,19 +9,20 @@
 
 #include <libxml/tree.h>
 
-typedef enum LWDirection {
+enum LWDirection {
 LW_DIRECTION_EAST=0,
 LW_DIRECTION_SOUTH=1,
 LW_DIRECTION_WEST=2,
 LW_DIRECTION_NORTH=3
 };
 
-typedef enum LWTurn {
+enum LWTurn {
 LW_TURN_LEFT=0,
 LW_TURN_RIGHT=1
 };
 
 class LWPiece;
+class LWBoard;
 class LWPixmap;
 class LWValue;
 
@@ -39,25 +40,27 @@ LWPiece *piece;
 LWPixmap *direction_pixmaps[4];
 gboolean inverted_grounds;
 LWPiece *getPieceNth (gint n);
-gboolean stepForward ();
-gboolean stepBack ();
 gboolean createOne (LWPixmap *pixmap, gint n);
-void pause ();
 public:
 LWWizard (LWPiece *a_piece);
+LWWizard (const LWWizard *wizard, LWBoard *board);
 ~LWWizard ();
 void restoreFromXML (xmlNode *node);
 void setDirection (LWDirection a_direction);
 void turn (LWTurn turn);
 LWDirection getDirection ();
 void setSpeed (gint speed);
+guint getPauseTime ();
 void hide ();
 void show ();
-void create (LWValue *value, gboolean wait);
-void go (gint n, gboolean wait);
+void create (LWValue *value);
+gboolean isCreatingPossible ();
+gboolean stepForward ();
+gboolean stepBack ();
 void setPiece (LWPiece *piece);
 LWPiece *getPiece ();
 void enableInvertedGrounds (gboolean inverted);
+LWPixmap *getDirectionPixmap (LWDirection a_direction);
 };
 
 #include "piece.h"
