@@ -1,6 +1,7 @@
 #include "include/support.h"
 #include "include/command.h"
 #include "include/message.h"
+#include "include/environment.h"
 
 class LWCommandAnd: public LWCommand {
 
@@ -12,7 +13,7 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	
 	gint r = args[0]->toInt() && args[1]->toInt();
 	
-	return new LWValue (r);
+	return new LWValue(LWEnvironment::getPixmapSet()->getPixmap(r == 1 ? "true" : "false"));
 }
 
 const gchar *getName ()
@@ -40,6 +41,14 @@ gboolean hasReturn()
 	return TRUE;
 }
 
+void checkArgument (guint n, LWValue *value)
+{
+	(void) n;
+	
+	if (FALSE == value->isVariable() && FALSE == value->checkRange())
+			throw new LWMessage (LW_ERROR_NumberOutOfRange);
+}
+
 void checkArgc (guint n)
 {
 	if (n != 2) 
