@@ -10,21 +10,38 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/paritycommand.h"
 #include "include/message.h"
 
-class LWCommandBegin: public LWParityCommand {
+class LWCommandBegin: public LWCommandSegment {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
-	(void) context;
 	(void) args;
 	
 	g_return_val_if_fail (argc == 0, NULL);
 	
+	if (context->instrPtr->prev != NULL) {
+	
+		LWPiece *piece = (LWPiece *) context->instrPtr->prev->data;
+		g_return_val_if_fail (piece != NULL, NULL);
+
+		LWSymbol *symbol = piece->getSymbol();
+		g_return_val_if_fail (symbol != NULL, NULL);
+		g_return_val_if_fail (TRUE == symbol->isCommand(), NULL);
+
+		LWCommand *cmd = (LWCommand *) symbol;		
+		
+		//When loop back to the previous command
+		if (TRUE == cmd->isLoop()) {
+			context->instrPtr = context->instrPtr->prev;
+			context->resume = TRUE;
+		}
+	}
+	
 	return NULL;
 }
 
@@ -38,21 +55,22 @@ gchar *getHint ()
 	return _("Open logical block");
 }
 
-gboolean isOpen ()
+gboolean matchNextCondition (LWCommand *cmd)
 {
+	(void) cmd;
 	return TRUE;
 }
 
-void matchWith (LWCommand *cmd)
+gboolean matchWith (LWCommand *cmd)
 {
-	if (g_strcasecmp (cmd->getName(), "end"))
+	if (cmd == NULL)
+		throw new LWMessage (LW_ERROR_UnmatchedBrace);
+	
+	if (g_ascii_strcasecmp (cmd->getName(), "end"))
 		throw new LWMessage (LW_ERROR_UnmatchedBrace);
 	
 	match();
-}
-
-gboolean matchAsLastOne ()
-{
+	
 	return TRUE;
 }
 
