@@ -10,13 +10,13 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/paritycommand.h"
 #include "include/message.h"
 
-class LWCommandBraceOpen: public LWParityCommand {
+class LWCommandBraceOpen: public LWCommandSegment {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
@@ -55,23 +55,32 @@ gboolean hasReturn()
 	return TRUE;
 }
 
-gboolean isOpen ()
+gboolean matchNextCondition (LWCommand *cmd)
 {
+	(void) cmd;
 	return TRUE;
 }
 
-void matchWith (LWCommand *cmd)
+gboolean matchWith (LWCommand *cmd)
 {
+	if (cmd == NULL)
+		throw new LWMessage (LW_ERROR_UnmatchedBrace);
+	
 	if (cmd->getName()[0] != ')')
 		throw new LWMessage (LW_ERROR_UnmatchedBrace);
 	
 	match();
+	
+	return TRUE;
 }
 
 void checkArgc (guint n)
 {
-	if (n != 1) 
+	if (n == 0) 
 		throw new LWMessage (LW_ERROR_EmptyBrace);
+	
+	if (n > 1) 
+		throw new LWMessage (LW_ERROR_WrongNumberOfArguments);
 }	
 
 };
