@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/command.h"
@@ -20,6 +20,10 @@ class LWCommandCalculate: public LWCommand {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
+	(void) context;
+	(void) argc;
+	(void) args;
+	
 	return NULL;
 }
 
