@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include <gdk/gdkkeysyms.h>
 #include "include/support.h"
@@ -23,27 +23,24 @@ class LWCommandControlGo: public LWCommand {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
+	(void) args;
+	
 	g_return_val_if_fail (argc == 0, NULL);
-	
-	while (1) {
-	
-		while (FALSE == g_queue_is_empty (context->queue_keys)) {
-			guint key = GPOINTER_TO_UINT(g_queue_pop_head (context->queue_keys));
-			if (TRUE == set_direction_by_key (context->wizard, key)) {
-				context->wizard->go(1, FALSE);
-				return NULL;
-			}
+
+	while (FALSE == g_queue_is_empty (context->queue_keys)) {
+		guint key = GPOINTER_TO_UINT(g_queue_pop_head (context->queue_keys));
+		if (TRUE == set_direction_by_key (context->wizard, key)) {
+			context->wizard->stepForward();;
+			return NULL;
 		}
-		
-		while (gtk_events_pending ())
-	  		gtk_main_iteration ();
-		
 	}
-
+	
+	context->resume = TRUE;
+	context->wait_for = LW_RESUME_KEYPRESS;
 	return NULL;
-}	
+}
 
-const gchar *getName (void) 
+const gchar *getName () 
 {
 	return "controlgo";
 }	
