@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/command.h"
@@ -61,9 +61,14 @@ gboolean hasReturn()
 
 void checkArgument (guint n, LWValue *value)
 {
-	if (n == 1)
-		if (0 == value->toInt())
+	if (FALSE == value->isVariable()) {
+		
+		if (n == 1 && 0 == value->toInt())
 			throw new LWMessage (LW_ERROR_DivisionByZero);
+
+		if (FALSE == value->checkRange())
+			throw new LWMessage (LW_ERROR_NumberOutOfRange);	
+	}
 }
 
 void checkArgc (guint n)
