@@ -10,44 +10,59 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/paritycommand.h"
 #include "include/message.h"
 
-class LWCommandDownTo: public LWParityCommand {
+class LWCommandDownTo: public LWCommandSegment {
 private:
-gboolean firstIter;
+gboolean has_step;
 public:
-LWCommandDownTo (): firstIter(TRUE) {}
+LWCommandDownTo (): has_step(FALSE) {}
 	
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
-	g_return_val_if_fail (argc == 1, NULL);
+	g_return_val_if_fail ((has_step == FALSE && argc == 1) || (has_step == TRUE && argc == 2), NULL);
 	g_return_val_if_fail (context->instrPtr->next != NULL, NULL);
 	g_return_val_if_fail (FALSE == g_queue_is_empty (context->stack), NULL);
 
-	LWValue *iterVariable = (LWValue *) g_queue_peek_head (context->stack);	
+	LWValue *iterVariable = (LWValue *) g_queue_peek_head (context->stack);
 	
-	if ((firstIter == TRUE && iterVariable->toInt() < args[0]->toInt()) ||
-		(firstIter == FALSE && iterVariable->toInt() <= args[0]->toInt()))
+	if (iterVariable->toInt() < args[0]->toInt())
 	{
-		firstIter = TRUE;
 		g_queue_pop_head (context->stack);
 		context->instrPtr = context->instrPtr->next->next;
-	} else 
-	if (firstIter == FALSE) {
-		LWValue *v = new LWValue(iterVariable->toInt() - 1);
+	}
+
+	return NULL;
+}
+
+LWValue *resume1 (LWContext *context, guint argc, LWValue *args[])
+{
+	g_return_val_if_fail ((has_step == FALSE && argc == 1) || (has_step == TRUE && argc == 2), NULL);
+	g_return_val_if_fail (context->instrPtr->next != NULL, NULL);
+	g_return_val_if_fail (FALSE == g_queue_is_empty (context->stack), NULL);
+
+	LWValue *iterVariable = (LWValue *) g_queue_peek_head (context->stack);
+
+	gint step = (has_step == TRUE) ? args[1]->toInt() : 1;	
+	
+	if (iterVariable->toInt() - step < args[0]->toInt())
+	{
+		g_queue_pop_head (context->stack);
+		context->instrPtr = context->instrPtr->next->next;
+	} else {
+		LWValue *v = new LWValue(iterVariable->toInt() - step);
 		iterVariable->set (v);
 		delete v;
-	} else 
-		firstIter = FALSE;
+	}
 	
 	return NULL;
 }
 
-const gchar *getName (void)
+const gchar *getName ()
 {
 	return "downto";
 }	
@@ -57,23 +72,53 @@ gchar *getHint ()
 	return _("Countdown to");
 }
 
+void checkArgument (guint n, LWValue *value)
+{
+	//For now checking step range is not implemented...
+	
+	if (n == 0)
+		if (FALSE == value->isVariable() && FALSE == value->checkRange())
+			throw new LWMessage (LW_ERROR_NumberOutOfRange);	
+}
+
 void checkArgc (guint n)
 {
-	if (n != 1) 
+	if (has_step == FALSE && n != 1) 
 		throw new LWMessage (LW_ERROR_WrongNumberOfArguments);
+	
+	if (has_step == TRUE && n != 2)
+		throw new LWMessage (LW_ERROR_PleaseSpecifyStep);
 }
 
-gboolean isOpen ()
+gboolean matchPrevCondition (LWCommand *cmd)
 {
-	return FALSE;	
+	(void) cmd;
+	return TRUE;
 }
 
-void matchWith (LWCommand *cmd)
+gboolean matchNextCondition (LWCommand *cmd)
 {
-	if (g_strcasecmp (cmd->getName(), "for2"))
+	return ((!g_ascii_strcasecmp (cmd->getName(), "break")) ||
+				(!g_ascii_strcasecmp (cmd->getName(), "continue")) ||
+				(!g_ascii_strcasecmp (cmd->getName(), "step"))) ? TRUE : FALSE;
+}
+
+gboolean matchWith (LWCommand *cmd)
+{
+	if (cmd == NULL)
+			throw new LWMessage (LW_ERROR_DowntoButWhereIsFor);
+
+	if (!g_ascii_strcasecmp (cmd->getName(), "step")) {
+		has_step = TRUE;
+		return TRUE;
+	}
+
+	if (g_ascii_strcasecmp (cmd->getName(), "for2"))
 			throw new LWMessage (LW_ERROR_DowntoButWhereIsFor);
 	
 	match();
+	
+	return TRUE;
 }
 
 gboolean isLoop ()
@@ -83,8 +128,8 @@ gboolean isLoop ()
 
 void reset1 ()
 {
-	firstIter = TRUE;
-	LWParityCommand::reset1();
+	has_step = FALSE;
+	LWCommandSegment::reset1();
 }
 
 };
