@@ -10,13 +10,13 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/paritycommand.h"
 #include "include/message.h"
 
-class LWCommandEnd: public LWParityCommand {
+class LWCommandEnd: public LWCommandSegment {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
@@ -24,7 +24,7 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	(void) argc;
 	(void) args;
 	
-	return NULL;
+	g_return_val_if_reached (NULL);
 }
 
 const gchar *getName ()
@@ -37,27 +37,28 @@ gchar *getHint ()
 	return _("Close logical block");
 }
 
-gboolean isOpen ()
+gboolean matchPrevCondition (LWCommand *cmd)
 {
-	return FALSE;
+	(void) cmd;
+	return TRUE;
 }
 
-void matchWith (LWCommand *cmd)
+gboolean matchWith (LWCommand *cmd)
 {
-	if (g_strcasecmp (cmd->getName(), "begin"))
+	if (cmd == NULL)
+		throw new LWMessage (LW_ERROR_UnmatchedBrace);		
+	
+	if (g_ascii_strcasecmp (cmd->getName(), "begin"))
 		throw new LWMessage (LW_ERROR_UnmatchedBrace);
 	
 	match();
+	
+	return TRUE;
 }
 
 gboolean canBeSkiped ()
 {
-	return TRUE;
-}
-
-gboolean matchAsLastOne ()
-{
-	return TRUE;
+	return isAlreadyMatched();
 }
 
 };
