@@ -10,11 +10,12 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/command.h"
 #include "include/message.h"
+#include "include/environment.h"
 
 class LWCommandGe: public LWCommand {
 	
@@ -24,9 +25,9 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	
 	g_return_val_if_fail (argc == 2, NULL);
 	
-	gint r = args[0]->toInt() >= args[1]->toInt();
+	gint r = args[0]->compare (args[1]);
 	
-	return new LWValue (r);
+	return new LWValue(LWEnvironment::getPixmapSet()->getPixmap(r >= 0 ? "true" : "false"));
 }
 
 const gchar *getName ()
@@ -54,6 +55,14 @@ gboolean hasReturn()
 	return TRUE;
 }
 
+void checkArgument (guint n, LWValue *value)
+{
+	(void) n;
+	
+	if (TRUE == value->isInt() && FALSE == value->isVariable() && FALSE == value->checkRange())
+			throw new LWMessage (LW_ERROR_NumberOutOfRange);
+}
+
 void checkArgc (guint n)
 {
 	if (n != 2) 
