@@ -10,13 +10,13 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/paritycommand.h"
 #include "include/message.h"
 
-class LWCommandIndexOpen: public LWParityCommand {
+class LWCommandIndexOpen: public LWCommandSegment {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
@@ -68,17 +68,23 @@ gboolean hasReturn()
 	return TRUE;
 }
 
-gboolean isOpen ()
+gboolean matchNextCondition (LWCommand *cmd)
 {
+	(void) cmd;
 	return TRUE;
 }
 
-void matchWith (LWCommand *cmd)
+gboolean matchWith (LWCommand *cmd)
 {
+	if (cmd == NULL)
+		throw new LWMessage (LW_ERROR_UnmatchedBrace);
+
 	if (cmd->getName()[0] != ']')
 		throw new LWMessage (LW_ERROR_UnmatchedBrace);
 	
 	match();
+	
+	return TRUE;
 }
 
 void checkArgc (guint n)
