@@ -10,13 +10,13 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/paritycommand.h"
 #include "include/message.h"
 
-class LWCommandIndexClose: public LWParityCommand {
+class LWCommandIndexClose: public LWCommandSegment {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
@@ -52,17 +52,23 @@ gboolean hasReturn()
 	return FALSE;
 }
 
-gboolean isOpen ()
+gboolean matchPrevCondition (LWCommand *cmd)
 {
-	return FALSE;
+	(void) cmd;
+	return TRUE;
 }
 
-void matchWith (LWCommand *cmd)
+gboolean matchWith (LWCommand *cmd)
 {
+	if (cmd == NULL)
+		throw new LWMessage (LW_ERROR_UnmatchedBrace);	
+	
 	if (cmd->getName()[0] != '[')
 		throw new LWMessage (LW_ERROR_UnmatchedBrace);
 	
 	match();
+	
+	return TRUE;
 }
 
 gboolean canBeSkiped ()
