@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/command.h"
@@ -21,6 +21,8 @@ class LWCommandMul: public LWCommand {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
+	(void) context;
+	
 	g_return_val_if_fail (argc == 2, NULL);
 	gint r = args[0]->toInt() * args[1]->toInt();
 	
@@ -52,6 +54,14 @@ gboolean hasReturn()
 	return TRUE;
 }
 
+void checkArgument (guint n, LWValue *value)
+{
+	(void) n;
+	
+	if (FALSE == value->isVariable() && FALSE == value->checkRange())
+			throw new LWMessage (LW_ERROR_NumberOutOfRange);
+}
+
 void checkArgc (guint n)
 {
 	if (n != 2) 
