@@ -10,11 +10,12 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/command.h"
 #include "include/message.h"
+#include "include/environment.h"
 
 class LWCommandNe: public LWCommand {
 	
@@ -24,9 +25,9 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	
 	g_return_val_if_fail (argc == 2, NULL);
 	
-	gint r = args[0]->toInt() != args[1]->toInt();
+	gint r = args[0]->compare (args[1]);
 	
-	return new LWValue (r);
+	return new LWValue(LWEnvironment::getPixmapSet()->getPixmap(r != 0 ? "true" : "false"));
 }
 
 const gchar *getName ()
