@@ -10,11 +10,12 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/command.h"
 #include "include/message.h"
+#include "include/environment.h"
 
 class LWCommandNot: public LWCommand {
 	
@@ -26,7 +27,7 @@ LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 	
 	gint r = ! args[0]->toInt();
 	
-	return new LWValue (r);
+	return new LWValue(LWEnvironment::getPixmapSet()->getPixmap(r == 1 ? "true" : "false"));
 }
 
 const gchar *getName ()
@@ -54,6 +55,14 @@ gboolean hasReturn()
 	return TRUE;
 }
 
+void checkArgument (guint n, LWValue *value)
+{
+	(void) n;
+	
+	if (FALSE == value->isVariable() && FALSE == value->checkRange())
+			throw new LWMessage (LW_ERROR_NumberOutOfRange);
+}
+
 void checkArgc (guint n)
 {
 	if (n != 1) 
