@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/command.h"
@@ -20,14 +20,16 @@ class LWCommandRand: public LWCommand {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
+	(void) context;	
+
 	g_return_val_if_fail (argc == 1, NULL);
 	
 	gint end = args[0]->toInt();
 
-	if (end <= 0)
-		end = 1;
+	if (end < 0)
+		end = 0;
 	
-	guint randv = g_random_int_range (1, end+1);
+	guint randv = g_random_int_range (0, end);
 
 	return new LWValue(randv);
 }	
@@ -39,7 +41,7 @@ const gchar *getName (void)
 
 gchar *getHint ()
 {
-	return _("Random number from 1 to value specified as argument");
+	return _("Random number from 0 to the value specified as argument minus one");
 }
 
 guint getPriority ()
@@ -57,6 +59,14 @@ gboolean hasReturn()
 	return TRUE;
 }
 
+void checkArgument (guint n, LWValue *value)
+{
+	(void) n;
+	
+	if (FALSE == value->isVariable() && FALSE == value->checkRange())
+			throw new LWMessage (LW_ERROR_NumberOutOfRange);
+}
+
 void checkArgc (guint n)
 {
 	if (n != 1) 
