@@ -10,16 +10,20 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/paritycommand.h"
 #include "include/message.h"
 
-class LWCommandRepeat: public LWParityCommand {
+class LWCommandRepeat: public LWCommandSegment {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
+	(void) context;
+	(void) argc;
+	(void) args;
+	
 	return NULL;
 }
 
@@ -39,17 +43,23 @@ void checkArgc (guint n)
 		throw new LWMessage (LW_ERROR_WrongNumberOfArguments);
 }
 
-gboolean isOpen ()
+gboolean matchNextCondition (LWCommand *cmd)
 {
+	(void) cmd;
 	return TRUE;
 }
 
-void matchWith (LWCommand *cmd)
+gboolean matchWith (LWCommand *cmd)
 {
-	if (g_strcasecmp (cmd->getName(), "until"))
-			throw new LWMessage (LW_ERROR_RepeatButWhereIsUntil);
+	if (cmd == NULL)
+		throw new LWMessage (LW_ERROR_RepeatButWhereIsUntil);
+	
+	if (g_ascii_strcasecmp (cmd->getName(), "until"))
+		throw new LWMessage (LW_ERROR_RepeatButWhereIsUntil);
 	
 	match();
+	
+	return TRUE;
 }
 
 };
