@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/command.h"
@@ -20,13 +20,15 @@ class LWCommandSet: public LWCommand {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
+	(void) context;
+	
 	g_return_val_if_fail (argc == 2, NULL);
 	g_return_val_if_fail (args[0]->isVariable() == TRUE, NULL);
 	
 	args[0]->set(args[1]);
 	
-	/* To jest zmienna, nie potrzeba tworzyć jej kopii przez konstruktor
-		kopiujący bo nie zostanie ona nigdy zwolniona */
+	/* It's a variable, it's not neccessery to make a copy by coping constructor,
+	because variable won't be freed. */
 	return args[0];
 }
 
