@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/command.h"
@@ -42,6 +42,14 @@ gchar *getHint ()
 	return _("Set horizontal position");
 }
 
+void checkArgument (guint n, LWValue *value)
+{
+	(void) n;
+	
+	if (FALSE == value->isVariable() && FALSE == value->checkRange())
+			throw new LWMessage (LW_ERROR_NumberOutOfRange);
+}
+
 void checkArgc (guint n)
 {
 	if (n != 1) 
