@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/command.h"
@@ -38,6 +38,15 @@ gchar *getHint ()
 	return _("Set speed");
 }
 
+void checkArgument (guint n, LWValue *value)
+{
+	(void) n;
+	
+	if (TRUE == value->toInt() < 0 || TRUE == value->toInt() > 9)
+			throw new LWMessage (LW_ERROR_NumberOutOfRange);
+}
+
+
 void checkArgc (guint n)
 {
 	if (n != 1) 
