@@ -10,13 +10,13 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/paritycommand.h"
 #include "include/message.h"
 
-class LWCommandUntil: public LWParityCommand {
+class LWCommandUntil: public LWCommandSegment {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
@@ -39,23 +39,47 @@ gchar *getHint ()
 	return _("Until");
 }
 
+void checkArgument (guint n, LWValue *value)
+{
+	(void) n;
+	
+	if (FALSE == value->isVariable() && FALSE == value->checkRange())
+			throw new LWMessage (LW_ERROR_NumberOutOfRange);
+}
+
 void checkArgc (guint n)
 {
 	if (n != 1) 
 		throw new LWMessage (LW_ERROR_WrongNumberOfArguments);
 }
 
-gboolean isOpen ()
+gboolean matchPrevCondition (LWCommand *cmd)
 {
-	return FALSE;	
+	(void) cmd;
+	return TRUE;
 }
 
-void matchWith (LWCommand *cmd)
+gboolean matchNextCondition (LWCommand *cmd)
 {
-	if (g_strcasecmp (cmd->getName(), "repeat"))
+	return ((!g_ascii_strcasecmp (cmd->getName(), "break")) ||
+				(!g_ascii_strcasecmp (cmd->getName(), "continue"))) ? TRUE : FALSE;
+}
+
+gboolean matchWith (LWCommand *cmd)
+{
+	if (cmd == NULL)
+			throw new LWMessage (LW_ERROR_UntilButWhereIsRepeat);
+	
+	if ((!g_ascii_strcasecmp (cmd->getName(), "break")) ||
+			(!g_ascii_strcasecmp (cmd->getName(), "continue")))
+				return FALSE;
+	
+	if (g_ascii_strcasecmp (cmd->getName(), "repeat"))
 			throw new LWMessage (LW_ERROR_UntilButWhereIsRepeat);
 	
 	match();
+	
+	return TRUE;
 }
 
 };
