@@ -10,13 +10,13 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
-#include "include/command.h"
+#include "include/paritycommand.h"
 #include "include/message.h"
 
-class LWCommandWhile: public LWCommand {
+class LWCommandWhile: public LWCommandSegment {
 
 LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
 {
@@ -44,12 +44,32 @@ gboolean isLoop ()
 	return TRUE;
 }
 
+void checkArgument (guint n, LWValue *value)
+{
+	(void) n;
+	
+	if (FALSE == value->isVariable() && FALSE == value->checkRange())
+		throw new LWMessage (LW_ERROR_NumberOutOfRange);	
+}
+
 void checkArgc (guint n)
 {
 	if (n != 1) 
 		throw new LWMessage (LW_ERROR_WrongNumberOfArguments);
 }
 
+gboolean matchNextCondition (LWCommand *cmd)
+{
+	return ((!g_ascii_strcasecmp (cmd->getName(), "break")) ||
+				(!g_ascii_strcasecmp (cmd->getName(), "continue"))) ? TRUE : FALSE;
+}
+
+gboolean matchWith (LWCommand *cmd)
+{
+	(void) cmd;
+	return FALSE;
+}
+
 };
 
 LWSymbol *new_LWCommandWhile()
