@@ -21,7 +21,14 @@ do
     $AWK -f symbols.cc.awk $i >> symbols.cc
 done
 
+for i in symbol*.cc
+do
+	if [ $i != symbols.cc ] ; then
+        	$AWK -f symbols.cc.awk $i >> symbols.cc
+	fi
+done
+
 cat >> symbols.cc <<EOT
 	return datalist;
 }
-EOT
\ No newline at end of file
+EOT
