@@ -12,3 +12,10 @@ for i in variable*.cc
 do
     $AWK -f symbols.h.awk $i >> symbols.h
 done
+
+for i in symbol*.cc
+do
+	if [ $i != symbols.cc ] ; then
+	    $AWK -f symbols.h.awk $i >> symbols.h
+	fi
+done
