@@ -10,16 +10,20 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/board.h"
+#include "include/environment.h"
+#include "include/wizard.h"
 
-static GtkTargetEntry target_table[] = {
+#define DEFAULT_PIECE_SIZE 40
+
+static const GtkTargetEntry target_table[] = {
   { (gchar *) "application/lwizard", GTK_TARGET_SAME_APP, 0 }
 };
 
-static guint n_targets = sizeof(target_table) / sizeof(target_table[0]);
+static const guint n_targets = sizeof(target_table) / sizeof(target_table[0]);
 
 static void clear_mark (LWPiece **marked_piece)
 {
@@ -28,10 +32,10 @@ static void clear_mark (LWPiece **marked_piece)
 
 static void zoom_inout (LWBoard *board)
 {
-	if (board->getPieceSize() < 40)
-		board->setPieceSize(40);
+	if (board->getPieceSize() < DEFAULT_PIECE_SIZE)
+		board->setPieceSize(DEFAULT_PIECE_SIZE);
 	else
-		board->setPieceSize(20);
+		board->setPieceSize(DEFAULT_PIECE_SIZE / 2);
 }
 
 static void shrink_w (LWBoard *board)
@@ -91,11 +95,12 @@ target_drag_data_received  (GtkWidget          *widget,
 							gpointer           userdata)
 
 {
-	/* Lista zmiennych nieużywanych */
+	/* List of unused varaibles */
 	(void) widget;
 	(void) x;
 	(void) y;
 	(void) info;
+	(void) userdata;
 	
 	if ((data->length == 0) || (data->format != 8)) {
     	gtk_drag_finish (context, FALSE, FALSE, time);
@@ -110,7 +115,7 @@ target_drag_data_received  (GtkWidget          *widget,
 	if (type == LW_TYPE_PROGRAM) {
 		if (TRUE == sourcepiece->getRow()->isPieceDummy(sourcepiece)) {
 	
-			/* Usuwanie pustych wierszy */
+			/* Remove empty rows */
 			if (NULL == sourcepiece->getRow()->getPieceNth(0)) 
 				if (FALSE == sourcepiece->getRow()->getBoard()->isRowDummy (sourcepiece->row)) {
 					sourcepiece->getRow()->getBoard()->removeRow (sourcepiece->row);
@@ -118,8 +123,8 @@ target_drag_data_received  (GtkWidget          *widget,
 					return;
 				} 
 			
-			/* Nie ruszać dodatkowych klocków na końcach wierszy,
-			 * w trybie programowania */
+			/* Don't touch additional pieces at the end of rows,
+			 * in programing mode */
 			gtk_drag_finish (context, TRUE, FALSE, time);
 			return;
 		}
@@ -128,6 +133,7 @@ target_drag_data_received  (GtkWidget          *widget,
 	}
 	
 	if (type == LW_TYPE_WORLD)
+		if (!sourcepiece->ifDNDWillMoveWizard())
 			sourcepiece->clear();
 	
 	gtk_drag_finish (context, TRUE, FALSE, time);
@@ -222,6 +228,7 @@ void LWBoard::init (LWType a_type)
 			gtk_table_attach (GTK_TABLE (widget), vbox, 0, 1, 0, 2,
 				(GtkAttachOptions) 0, (GtkAttachOptions) 0, 0, 0);
 			buildResizeBar ();
+	
 			gtk_widget_show (widget);
 			break;			
 		
@@ -240,7 +247,7 @@ void LWBoard::init (LWType a_type)
 		
 	    	g_signal_connect ( G_OBJECT(widget), "drag_data_received",
 	 			G_CALLBACK(target_drag_data_received), NULL);
-
+		
 			break;
 		
 		case LW_TYPE_PROGRAM:
@@ -261,12 +268,22 @@ void LWBoard::init (LWType a_type)
 	\param type Typ tworzonej planszy
 */
 LWBoard::LWBoard (LWType a_type):
-list_row(NULL), dummy_row(NULL), marked_piece(NULL), 
-enable_grid(FALSE), boardset(NULL)
+list_row(NULL), dummy_row(NULL), marked_piece(NULL), piecesize(DEFAULT_PIECE_SIZE),
+enable_grid(FALSE), boardset(NULL), wizard(NULL)
 				
 {
 	init (a_type);
-	setPieceSize(40);
+	setPieceSize(piecesize);
+
+	if (type == LW_TYPE_WORLD) {
+		LWRow *row = new LWRow (this);
+		addRow (row);
+		LWPiece *piece = new LWPiece (row);
+		row->addPiece (piece);
+
+		wizard = new LWWizard (piece);
+		wizard->restoreFromXML (LWEnvironment::getWizardXML());	
+	}
 }
 
 /*! 
@@ -277,11 +294,21 @@ enable_grid(FALSE), boardset(NULL)
 	zestaw. 
 */
 LWBoard::LWBoard (LWBoardSet *a_boardset): 
-list_row(NULL), dummy_row(NULL), marked_piece(NULL),
-enable_grid(FALSE)
+list_row(NULL), dummy_row(NULL), marked_piece(NULL), piecesize(DEFAULT_PIECE_SIZE),
+enable_grid(FALSE), wizard(NULL)
 {
 	init (a_boardset->getType());
-	setPieceSize(40);
+	setPieceSize(piecesize);
+
+	if (type == LW_TYPE_WORLD) {
+		LWRow *row = new LWRow (this);
+		addRow (row);
+		LWPiece *piece = new LWPiece (row);
+		row->addPiece (piece);
+
+		wizard = new LWWizard (piece);
+		wizard->restoreFromXML (LWEnvironment::getWizardXML());	
+	}
 	
 	boardset = a_boardset;
 }
@@ -293,6 +320,11 @@ enable_grid(FALSE)
 */
 LWBoard::~LWBoard ()
 {
+	if (wizard != NULL) {
+		delete wizard;
+		wizard = NULL;
+	}
+	
 	clear();
 
 	if (dummy_row != NULL)
@@ -310,17 +342,22 @@ LWBoard::~LWBoard ()
 	\param type Typ tworzonej planszy 
 */
 LWBoard::LWBoard (const LWBoard *board, LWType a_type):
-list_row(NULL), dummy_row(NULL), marked_piece(NULL),
-enable_grid(FALSE), boardset(NULL)
+list_row(NULL), dummy_row(NULL), marked_piece(NULL), piecesize(board->piecesize),
+enable_grid(FALSE), boardset(NULL), wizard(NULL)
 {
 	init (a_type);
-	setPieceSize(board->piecesize);
+	setPieceSize(piecesize);
 	
 	for (GSList *l=board->list_row; l != NULL; l = l->next) {
 		LWRow *row = (LWRow *) l->data;
 		LWRow *newrow = new LWRow (row, this);
 		addRow (newrow);
 	}
+	
+	if (board->wizard != NULL) {
+		if (wizard != NULL) delete wizard;
+		wizard = new LWWizard (board->wizard, this);
+	}
 }
 
 /*!	\brief Rekonstrukcja elementów planszy na podstawie opisu XML
@@ -337,6 +374,14 @@ void LWBoard::restoreFromXML (xmlNode *node)
 
 	gchar *title = (gchar *) xmlGetProp (node, (xmlChar *) "title");	
 	gchar *piecesizestr = (gchar *) xmlGetProp (node, (xmlChar *) "piecesize");
+	gchar *wizardposxstr = (gchar *) xmlGetProp (node, (xmlChar *) "wizardposx");
+	gchar *wizardposystr = (gchar *) xmlGetProp (node, (xmlChar *) "wizardposy");
+	gchar *wizarddirectionstr = (gchar *) xmlGetProp (node, (xmlChar *) "wizarddirection");
+	
+	if (wizard != NULL) {
+		delete wizard;
+		wizard = NULL;
+	}
 	
 	clear();
 
@@ -354,6 +399,34 @@ void LWBoard::restoreFromXML (xmlNode *node)
 		row->restoreFromXML (n);
 		addRow (row);
 	}
+	
+	if (type == LW_TYPE_WORLD)
+		if (wizardposxstr != NULL && wizardposystr != NULL && wizarddirectionstr != NULL) {
+			gint wizardposx = atoi (wizardposxstr);
+			gint wizardposy = atoi (wizardposystr);
+			gint wizarddirection = atoi (wizarddirectionstr) - 1;
+		
+			LWRow *row = getRowNth (wizardposy);
+			g_return_if_fail (row != NULL);
+					
+			LWPiece *piece = row->getPieceNth (wizardposx);
+			g_return_if_fail (piece != NULL);
+			
+			wizard = new LWWizard (piece);
+			wizard->restoreFromXML (LWEnvironment::getWizardXML());	
+			wizard->setDirection ((LWDirection) (wizarddirection));			
+		} else  {
+			g_return_if_fail (list_row != NULL);
+			
+			LWRow *row = (LWRow *) list_row->data;
+			g_return_if_fail (row != NULL);
+
+			LWPiece *piece = row->getPieceNth (0);
+			g_return_if_fail (piece != NULL);
+			
+			wizard = new LWWizard (piece);
+			wizard->restoreFromXML (LWEnvironment::getWizardXML());	
+		}
 }
 
 /*! \brief Zapis elementów planszy w pastaci opisu XML
@@ -374,12 +447,26 @@ void LWBoard::storeToXML (xmlNode *parent_node)
 	gchar *s = g_strdup_printf ("%u", piecesize);
 	xmlNewProp (node, (xmlChar *) "piecesize", (xmlChar *) s);
 	g_free (s);
+					
+	if (wizard != NULL) {
+		LWPiece *piece = wizard->getPiece();
+		s = g_strdup_printf ("%i", piece->getRow()->getPieceIndex (piece));
+		xmlNewProp (node, (xmlChar *) "wizardposx", (xmlChar *) s);
+		g_free(s);
+	
+		s = g_strdup_printf ("%i", getRowIndex (piece->getRow()));
+		xmlNewProp (node, (xmlChar *) "wizardposy", (xmlChar *) s);
+		g_free(s);
+		
+		s = g_strdup_printf ("%u", (guint) wizard->getDirection() + 1);
+		xmlNewProp (node, (xmlChar *) "wizarddirection", (xmlChar *) s);
+		g_free(s);
+	}
 	
 	for (GSList *l = list_row; l != NULL; l = l->next) {
 		LWRow *row = (LWRow *) l->data;
 		row->storeToXML (node);
 	}
-	
 }
 
 /*! \brief Dodanie wiersza do planszy
@@ -453,8 +540,8 @@ void LWBoard::removeRow (LWRow *row)
 	g_return_if_fail (row != NULL);
 	g_return_if_fail (row->getBoard() == this);
 	
-	list_row = g_slist_remove (list_row, (gpointer) row);
 	delete row;
+	list_row = g_slist_remove (list_row, (gpointer) row);
 }
 
 /*! \brief Pozycja wiersza w planszy
@@ -516,8 +603,8 @@ void LWBoard::setSize (guint width, guint height)
 	/* Zmniejsz liczbe wierszy jeśli potrzeba */
 	while (NULL != (l = g_slist_nth (list_row, height))) {
 		LWRow *row = (LWRow *) l->data;
-		g_slist_delete_link (list_row, l);
 		delete row;
+		list_row = g_slist_delete_link (list_row, l);
 	}
 	
 	/* Zwiększ liczbę wierszy jeśli potrzeba */
@@ -619,6 +706,8 @@ gboolean LWBoard::isGridEnabled ()
 */
 void LWBoard::clear ()
 {
+	g_return_if_fail (wizard == NULL);
+		
 	for (GSList *l=list_row; l != NULL; l = l->next) {
 		LWRow *row = (LWRow *) l->data;
 		delete row;		
@@ -669,11 +758,22 @@ void LWBoard::unmarkPiece ()
 	marked_piece = NULL;
 }
 
-/*! \brief Pobieranie kontrolki
- 
-	Pobiera kontrolkę (ang. widget) zawierająca planszę
+/*! \brief Get wizard attached to a board 
 
-	\return Zwrócona kontrolka
+	It gets wizard object that belong to that board
+
+	\return The wizard
+*/
+LWWizard *LWBoard::getWizard ()
+{
+	return wizard;
+}
+
+/*! \brief Get the widget
+ 
+	It gets the widget of the board
+
+	\return The widget
 */
 GtkWidget *LWBoard::getWidget ()
 {
