@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
-/* (C) Marcin Kwadrans <quar@vitea.pl> */
+/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/boardset.h"
@@ -27,34 +27,37 @@ static void try_translate_title (gchar **title)
 {
 gchar *newtitle = NULL;
 	
-	if (!g_strcasecmp (*title, "Icons"))
+	if (!g_ascii_strcasecmp (*title, "Icons"))
 		newtitle = g_strdup (_("Icons"));
 	else
-	if (!g_strcasecmp (*title, "House"))
+	if (!g_ascii_strcasecmp (*title, "House"))
 		newtitle = g_strdup (_("House"));
 	else
-	if (!g_strcasecmp (*title, "Digits"))
+	if (!g_ascii_strcasecmp (*title, "Blackboard"))
+		newtitle = g_strdup (_("Blackboard"));
+	else
+	if (!g_ascii_strcasecmp (*title, "Digits"))
 		newtitle = g_strdup (_("Digits"));
 	else
-	if (!g_strcasecmp (*title, "Alphabet"))
+	if (!g_ascii_strcasecmp (*title, "Alphabet"))
 		newtitle = g_strdup (_("Alphabet"));
 	else
-	if (!g_strcasecmp (*title, "Commands"))
+	if (!g_ascii_strcasecmp (*title, "Commands"))
 		newtitle = g_strdup (_("Commands"));
 	else
-	if (!g_strcasecmp (*title, "Wizard"))
+	if (!g_ascii_strcasecmp (*title, "Wizard"))
 		newtitle = g_strdup (_("Wizard"));
 	else
-	if (!g_strcasecmp (*title, "Variables"))
+	if (!g_ascii_strcasecmp (*title, "Variables"))
 		newtitle = g_strdup (_("Variables"));
 	else
-	if (!g_strcasecmp (*title, "Math"))
+	if (!g_ascii_strcasecmp (*title, "Math"))
 		newtitle = g_strdup (_("Math"));
 	else
-	if (!g_strcasecmp (*title, "Conditions and loops"))
+	if (!g_ascii_strcasecmp (*title, "Conditions and loops"))
 		newtitle = g_strdup (_("Conditions and loops"));
 	else
-	if (!g_strcasecmp (*title, "Other"))
+	if (!g_ascii_strcasecmp (*title, "Other"))
 		newtitle = g_strdup (_("Other"));
 	
 	if (newtitle != NULL) {
