@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/environment.h"
@@ -33,8 +33,6 @@ GData *LWEnvironment::symbols=NULL;
 LWProgram *LWEnvironment::program=NULL;
 gboolean LWEnvironment::enabled_grid=FALSE;
 
-extern GData *get_symbols ();
-
 /*! \brief Tworzy obszar z suwakiem
 
 	Tworzy obszar z suwakiem, modyfikując dodatkowo kolor tła obszaru.
@@ -63,13 +61,16 @@ static GtkWidget *create_scrolled (GtkWidget *child)
 
 	Inicjuje środowisko, odczytując ustawienia z pliku
 */
-void LWEnvironment::init ()
+void LWEnvironment::init (GData *the_symbols)
 {
 static gboolean inited=FALSE;
 xmlDoc *doc=NULL;
 	
 	g_assert (inited == FALSE);
+	g_assert (the_symbols != NULL);
+	
 	inited = TRUE;
+	symbols = the_symbols;
 	
 	xmlNode *root_node = initializeXMLTree (doc);
 	g_assert (root_node != NULL);
@@ -85,13 +86,12 @@ xmlDoc *doc=NULL;
 	world_paned = gtk_vpaned_new ();
 	g_object_ref (G_OBJECT (world_paned));
 	gtk_widget_show (world_paned);
-	
+
 	g_assert (root_node->children->next->next != NULL);
 	icons = new LWBoardSet (LW_TYPE_ICONS);
 	icons->restoreFromXML (root_node->children->next->next);
 	gtk_paned_add1 (GTK_PANED (world_paned), icons->getWidget());
-		
-	symbols = get_symbols();
+
 	program_paned = gtk_vpaned_new ();
 	g_object_ref (G_OBJECT (program_paned));
 	gtk_widget_show (program_paned);
@@ -174,10 +174,10 @@ xmlNode *LWEnvironment::initializeXMLTree (xmlDocPtr &doc)
 
 #ifdef _WIN32
 	gchar *t = g_win32_get_package_installation_subdirectory(NULL, NULL, "share\\littlewizard");
-	gchar *filename = g_build_filename (t, "lw.xml", NULL);
+	gchar *filename = g_build_filename (t, "littlewizard.xml", NULL);
 	g_free (t);
 #else
-	gchar *filename = g_build_filename (PACKAGE_DATA_DIR, PACKAGE, "lw.xml", NULL);
+	gchar *filename = g_build_filename (PACKAGE_DATA_DIR, PACKAGE, "littlewizard.xml", NULL);
 #endif
 	
     /* Włącz opcje ignorowania białych znaków */
@@ -344,7 +344,7 @@ LWProgram *LWEnvironment::getProgram ()
 	\param file Nazwa pliku
 	\return Nazwa pliku wraz ze ścieżką bezwzględną
 */
-gchar *LWEnvironment::buildPixmapFilename (gchar *file)
+gchar *LWEnvironment::buildPixmapFilename (const gchar *file)
 {
 #ifdef _WIN32
 	gchar *t = g_win32_get_package_installation_subdirectory(NULL, NULL, "share\\pixmaps");
