@@ -10,25 +10,25 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/message.h"
 
-/*! \brief Konstruktor komunikatu
+/*! \brief Message constructor
 
-	Tworzy komunikat na podstawie typu.
-	\param a_message Typ wiadomości
+	It crates message basing on type
+	\param a_message Message type
 */
 LWMessage::LWMessage (LWMsg a_message): piece(NULL), program(NULL)
 {
 	message = a_message;
 }
 
-/*! \brief Przypisanie klocka
+/*! \brief Assign piece to the message
 
-	Przypisuje klocek, z którym związany jest komunikat
-	\param a_piece Klocek
+	It assigns piece to the message
+	\param a_piece A piece
 */
 void LWMessage::setPiece (LWPiece *a_piece)
 {
@@ -42,26 +42,11 @@ void LWMessage::setPiece (LWPiece *a_piece)
 	}
 }
 
-/*! \brief Przypisanie programu
+/*! \brief Show the message
 
-	Przypisuje program, w którym wystąpił błąd. Po zamknięciu
-	okienka z wiadomością przez użytkownika, program zostanie
-	zniszczony.
-	\param a_program Program
-*/
-void LWMessage::setProgram (LWProgram *a_program)
-{
-	g_return_if_fail (a_program != NULL);
-	g_return_if_fail (program == NULL);
-	
-	program = a_program;
-}
-
-/*! \brief Wyświetlenie komunikatu
-
-	Wyświetla komunikat. Przed wywołaniem tej metody należy skojarzyć
-	z wiadomością klocek, którego tyczy komunikat, ponieważ wewnątrz
-	tej metody zostanie on oznaczony.
+	It show the message. Before using that method, message should be
+	has assigned piece, because that piece will be marked inside this
+	method.
 */
 void LWMessage::show ()
 {
@@ -75,10 +60,7 @@ void LWMessage::show ()
 			type = GTK_MESSAGE_INFO;
 			break;
 		case LW_ERROR_WrongNumberOfArguments:
-			if (piece != NULL)
-				msg = _("Wrong number of arguments");
-			else
-				msg = _("Begin program with command for wizard");
+			msg = _("Wrong number of arguments");
 			break;
 		case LW_ERROR_LValueIsNotVariable:
 			msg = _("Left side of operator is not variable");
@@ -121,6 +103,31 @@ void LWMessage::show ()
 			break;
 		case LW_ERROR_IndexOutOfRange:
 			msg = _("Index of array is out of range");
+			break;
+		case LW_ERROR_BreakNotInALoop:
+			msg = _("Command 'break' not in a loop");
+			break;
+		case LW_ERROR_ContinueNotInALoop:
+			msg = _("Command 'continue' not in a loop");
+			break;
+		case LW_ERROR_ElseButWhereIsIf:
+			msg = _("There is command 'else', but there is no command 'if'.");
+			break;
+		case LW_ERROR_StepButWhereIsFor:
+			msg = _("There is command 'step', but there is no command 'for'.");
+			break;
+		case LW_ERROR_PleaseSpecifyStep:
+			msg = _("Please specify value of the step.");
+			break;
+		case LW_ERROR_NumberOutOfRange:
+			msg = _("Value of an argument is too big or too small.");
+			break;
+		case LW_ERROR_DontUseSpecial:
+			msg = _("Don't use world variable as an argument.");
+			break;
+		case LW_ERROR_BeginProgramWithCommand:
+			msg = _("Begin program with command for wizard");
+			break;
 	}
 	
 	dialog = gtk_message_dialog_new (NULL,
@@ -131,7 +138,9 @@ void LWMessage::show ()
 					
   	gtk_dialog_run (GTK_DIALOG (dialog));
   	gtk_widget_destroy (dialog);
-	
-	if (program != NULL)
-		delete program;
+}
+
+guint LWMessage::getId ()
+{
+	return (guint) message;
 }
