@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/paritycommand.h"
@@ -19,7 +19,7 @@
 
 	Konstruktor dwu członowego polecenia
 */
-LWParityCommand::LWParityCommand (): matched(FALSE)
+LWCommandSegment::LWCommandSegment(): matched(FALSE)
 {
 }
 
@@ -28,16 +28,28 @@ LWParityCommand::LWParityCommand (): matched(FALSE)
 	Czy polecenie jest dwuczłonowe
 	\return Zawsze zwraca prawdę
 */
-gboolean LWParityCommand::isParity ()
+gboolean LWCommandSegment::isSegment ()
 {
 	return TRUE;
 }
 
+gboolean LWCommandSegment::matchNextCondition(LWCommand *cmd)
+{
+	(void) cmd;
+	return FALSE;
+}
+
+gboolean LWCommandSegment::matchPrevCondition(LWCommand *cmd)
+{
+	(void) cmd;
+	return FALSE;
+}
+
 /*! \brief Dopasowuje polecenie
 
 	Oznacza polecenia jako już dopasowane z jego końcem
 */
-void LWParityCommand::match ()
+void LWCommandSegment::match ()
 {
 	matched = TRUE;
 }
@@ -47,7 +59,7 @@ void LWParityCommand::match ()
 	Czy polecenie jest już dopasowane
 	\return Zwraca prawdę jeśli było już dopasowane w przeciwnym razie fałsz
 */
-gboolean LWParityCommand::isAlreadyMatched ()
+gboolean LWCommandSegment::isAlreadyMatched ()
 {
 	return matched;
 }
@@ -56,27 +68,7 @@ gboolean LWParityCommand::isAlreadyMatched ()
 
 	Zeruje polecenie czyniąc je niedopasowanym
 */
-void LWParityCommand::reset1 ()
+void LWCommandSegment::reset1 ()
 {
 	matched = FALSE;
 }
-
-/*! \brief Czy próba sprawdzenia doposowania ma być dokonywana jako
-	ostatnia. 
-
-	Polecenie pozwala na prawidłowe wskazanie błędu występującego
-	przy przecięciu dwóch operatorów parzystych, np. begin to,
-	for end, begin until, repeat end. We wszystkich tych przypadkach
-	bardziej sensowne wydaje się wyświetlenie błędu związanego
-	z poleceniami for, to, dowto, repeat, until niz begin czy end.
-	Funkcja pozwala zaznaczyć polecenia, które przy nieudanym
-	dopasowaniu zwracają mało czytelne komunikaty błędów, tak
-	jak w przypadku begin czy end. Nie przeciążona funkcja zwraca
-	FAŁSZ.
-	\return Jęśli próba dopasowania ma odbyć się na końcu zwracana
-	jest PRAWDA, w przeciwnym wypadku FAŁSZ.
-*/	
-gboolean LWParityCommand::matchAsLastOne ()
-{
-	return FALSE;
-}
