@@ -10,21 +10,23 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/piece.h"
 #include "include/environment.h"
+#include "include/wizard.h"
+#include <cstring>
 
 #define BACKWARD_COMPATIBILITY 1
 
-static GtkTargetEntry target_table[] = {
+static const GtkTargetEntry target_table[] = {
   { (gchar *) "application/lwizard", GTK_TARGET_SAME_APP, 0 }
 };
 
-static guint n_targets = sizeof(target_table) / sizeof(target_table[0]);
+static const guint n_targets = sizeof(target_table) / sizeof(target_table[0]);
 
-static gboolean dndpermissions_table[5][5] = {
+static const gboolean dndpermissions_table[5][5] = {
 /* FROM / TO 	   ICONS, COMMANDS, WORLD, PROGRAM, PLAYGROUND */
 /* ICONS      */ { FALSE,    FALSE,  TRUE,    TRUE,      FALSE },
 /* COMMANDS   */ { FALSE,    FALSE, FALSE,    TRUE,      FALSE },
@@ -68,7 +70,7 @@ target_drag_data_received  (GtkWidget          *widget,
 							gpointer           userdata)
 
 {
-	/* Lista zmiennych nieużywanych */
+	/* List of unused variables */
 	(void) widget;
 	(void) x;
 	(void) y;
@@ -85,15 +87,15 @@ target_drag_data_received  (GtkWidget          *widget,
 
 	if (TRUE == sourcepiece->getRow()->isPieceDummy(sourcepiece)) {
 		
-		/* Nie ruszać dodatkowych klocków na końcach wierszy,
-		 * w trybie programowania */
+		/* Don't touch additional pieces at the end of lines,
+		 * in programming mode */
 		gtk_drag_finish (context, TRUE, FALSE, time);
 		return;
 	}
 	
-	/* Przenoszenie jedynego klocka w lini do tej samej lini
-	 * nie ma sensu, dodatkowo powoduje naruszenie ochrony pamięci
-	 * w niektórych sytuacjach, niedopuść do takiej sytuacji */
+	/* Moving single piece in line to the same line
+	 * doesn't make a sens, additionaly it can produce seg. fault
+	 * in some cases, don't allow such situation */
 	if ((sourcepiece->row == destpiece->row) &&
 		(NULL == sourcepiece->row->getPieceNth(1))) {
 			gtk_drag_finish (context, TRUE, FALSE, time);
@@ -106,27 +108,42 @@ target_drag_data_received  (GtkWidget          *widget,
 			return;
 	}
 
-	if (TRUE == sourcepiece->isEnter())
-		if (destpiece->getRow()->getBoard()->getType() == LW_TYPE_PROGRAM) {
-			destpiece->getRow()->splitBefore (destpiece);
-			gtk_drag_finish (context, TRUE, FALSE, time);
-			return;
-		}
-	
-	/* Jeśli wynegocjowano akcję kopiowania */	
-	if (context->action == GDK_ACTION_COPY) {
+	LWSymbol *symbol = sourcepiece->getSymbol();
+								
+	/* Negotiated action : copying */	
+	if (context->action == GDK_ACTION_COPY || context->action == GDK_ACTION_LINK) {
+		if (symbol != NULL)
+			symbol->onDndCopy(sourcepiece, destpiece);
+		else
 		if (LW_TYPE_PROGRAM == destpiece->getRow()->getBoard()->getType()) {
 			LWPiece *newpiece = new LWPiece (sourcepiece, destpiece->getRow());
 			destpiece->getRow()->insertPieceBefore (newpiece, destpiece);
-		} else
-			destpiece->copy (sourcepiece);
+		} 
+		else
+			destpiece->setBackgroundPixmap (sourcepiece->getBackgroundPixmap());
 	} 
 	
-	/* Jeśli wynegocjowano akcję przenoszonia */
+	/* Negotiated action: moving */
 	if (context->action == GDK_ACTION_MOVE) {
-		LWPiece *newpiece = new LWPiece (sourcepiece, destpiece->row);
-		destpiece->getRow()->insertPieceBefore (newpiece, destpiece);
-		sourcepiece->getRow()->removePiece (sourcepiece);
+		if (symbol != NULL)
+			symbol->onDndMove(sourcepiece, destpiece);		
+		else
+		if (sourcepiece->ifDNDWillMoveWizard()) {
+			LWWizard *wizard = destpiece->getRow()->getBoard()->getWizard();
+			g_return_if_fail (wizard != NULL);
+			wizard->setPiece(destpiece);
+		} 
+		else 
+		if (LW_TYPE_WORLD == destpiece->getRow()->getBoard()->getType()) {
+			destpiece->setBackgroundPixmap (sourcepiece->getBackgroundPixmap());
+			sourcepiece->setBackgroundPixmap(NULL);
+		}
+		else 
+		{
+			LWPiece *newpiece = new LWPiece (sourcepiece, destpiece->row);
+			destpiece->getRow()->insertPieceBefore (newpiece, destpiece);
+			sourcepiece->getRow()->removePiece (sourcepiece);			
+		}
 	}
 
 	gtk_drag_finish (context, TRUE, FALSE, time);
@@ -149,7 +166,8 @@ composite_image(GtkWidget *image,
 	
 	g_return_if_fail (image != NULL);
 	g_return_if_fail (size > 0);
-	
+					
+					
 	GdkPixbuf *tmppixbuf=NULL;
 	
 	if ((backpixmap == NULL) && (forepixmap == NULL)) return;
@@ -164,13 +182,13 @@ composite_image(GtkWidget *image,
 	
 		if (forepixmap != NULL)
 			gdk_pixbuf_composite (forepixmap->getPixbuf(), tmppixbuf, 
-						0, 0, /* Współrzędne lewego górnego rogu */
-						size, size, /* Wielkość skalowanego obrazka */
-						0.0, 0.0, /* offset, nie przycinaj lewej strony i góry obrazka */
+						0, 0, /* Cooridinates of left top corner */
+						size, size, /* Size of scaled image */
+						0.0, 0.0, /* offset, don't crop left and top side of an image */
 						(gdouble) size / (gdouble) gdk_pixbuf_get_width (forepixmap->getPixbuf()),
 						(gdouble) size / (gdouble) gdk_pixbuf_get_height (forepixmap->getPixbuf()),
-						GDK_INTERP_BILINEAR, /* interpolacja */
-						255); /* Alfa dla obrazka pod spodem */
+						GDK_INTERP_BILINEAR, /* interpolation */
+						255); /* Alfa for background image */
 	} else {
 		if ((gdk_pixbuf_get_width (forepixmap->getPixbuf()) == size) &&
 			(gdk_pixbuf_get_height (forepixmap->getPixbuf()) == size)) {
@@ -186,19 +204,23 @@ composite_image(GtkWidget *image,
 	g_object_unref (G_OBJECT (tmppixbuf));
 }
 
-/*! \brief Wskazówka
+/*! \brief Tip
 
-	Wskazówka skojarzona z klockiem
+	Tip associated with a piece
 */
 GtkTooltips *LWPiece::tooltips=NULL;
 
 void LWPiece::init (LWRow *row)
 {
-	guint size = row->getBoard()->getPieceSize();
+	g_return_if_fail ( row != NULL );
+	g_return_if_fail ( row->getBoard() != NULL );
 
+	guint size = row->getBoard()->getPieceSize();
+	
 	widget = gtk_event_box_new();
 	gtk_widget_set_size_request (widget, size, size);
 	gtk_widget_show (widget);
+	
 	attach(row);
 	
 	/* Tworzy grupę wskazówek, jeśli jeszcze nie istneje,
@@ -216,7 +238,7 @@ void LWPiece::init (LWRow *row)
 	\param row Klocek będzie przynależał do wiersza
 */
 LWPiece::LWPiece (LWRow *row):
-	backpixmap(NULL), forepixmap(NULL), symbol(NULL), image(NULL), inverted_grounds(FALSE), is_enter(FALSE)
+	backpixmap(NULL), forepixmap(NULL), symbol(NULL), image(NULL), inverted_grounds(FALSE)
 {
 	init (row);	
 }
@@ -228,7 +250,7 @@ LWPiece::LWPiece (LWRow *row):
 	\param pixmap Klocek będzie zawierał ikonę 
 */
 LWPiece::LWPiece (LWRow *row, LWPixmap *pixmap): 
-	backpixmap(NULL), forepixmap(NULL), symbol(NULL), image(NULL), inverted_grounds(FALSE), is_enter(FALSE)
+	backpixmap(NULL), forepixmap(NULL), symbol(NULL), image(NULL), inverted_grounds(FALSE)
 {
 	init (row);
 	
@@ -242,7 +264,7 @@ LWPiece::LWPiece (LWRow *row, LWPixmap *pixmap):
 	\param pixmap Klocek będzie zawierał ikonę 
 */
 LWPiece::LWPiece (const LWPiece *piece, LWRow *row): 
-	backpixmap(NULL), forepixmap(NULL), symbol(NULL), image(NULL), inverted_grounds(FALSE), is_enter(FALSE)
+	backpixmap(NULL), forepixmap(NULL), symbol(NULL), image(NULL), inverted_grounds(FALSE)
 {
 	init (row);
 	
@@ -255,8 +277,17 @@ LWPiece::LWPiece (const LWPiece *piece, LWRow *row):
 */
 LWPiece::~LWPiece ()
 {
+	LWWizard *wizard = row->getBoard()->getWizard();
+		
+	if (wizard != NULL)
+		if (wizard->getPiece() == this) {
+			guint x = row->getPieceIndex(this);
+			g_assert (x > 0);
+			wizard->setPiece (row->getPieceNth (x-1));
+		}
+		
 	clear ();
-	
+		
 	gtk_widget_destroy (widget);
 }
 
@@ -288,18 +319,11 @@ void LWPiece::restoreFromXML (xmlNode *node)
 		
 		xmlFree (name);
 	}
-		
-	xmlChar *isenter = xmlGetProp (node, (xmlChar *) "enter");
-
-	if (isenter != NULL) {
-		if (!xmlStrcasecmp (isenter, (xmlChar *) "1"))
-			is_enter = TRUE;
-		xmlFree (isenter);
-	}
 
 	gchar *symbolname = (gchar *) xmlGetProp (node, (xmlChar *) "symbol");
 
 #if BACKWARD_COMPATIBILITY
+	
 	/* Kompatybilność wsteczna - Backward compatibilty with ver 1.0.x*/
 	if (symbolname == NULL)
 		symbolname = (gchar *) xmlGetProp (node, (xmlChar *) "cmd");
@@ -319,7 +343,7 @@ void LWPiece::restoreFromXML (xmlNode *node)
 			setSymbolWithId (symbolname, id);	
 		else
 			setSymbol (symbolname);
-		
+			
 		xmlFree (symbolname);
 	}
 	
@@ -387,9 +411,14 @@ void LWPiece::setSymbol (const gchar *symbolname)
 {
 	g_return_if_fail (symbolname != NULL);
 
+	if (symbol != NULL && TRUE == symbol->canClone())
+		delete symbol;
+		
 	symbol = LWSymbol::factory (symbolname);
 
 	g_return_if_fail (symbol != NULL);
+		
+	symbol->onAttach(this);
 	
 	gtk_tooltips_set_tip (tooltips, widget, 
 			symbol->getHint(), symbol->getHint());
@@ -406,10 +435,15 @@ void LWPiece::setSymbolWithId (const gchar *symbolname, guint id)
 {
 	g_return_if_fail (symbolname != NULL);
 
+	if (symbol != NULL && TRUE == symbol->canClone())
+		delete symbol;
+	
 	symbol = LWSymbol::factoryId (symbolname, id);
 
 	g_return_if_fail (symbol != NULL);
 	
+	symbol->onAttach(this);
+	
 	gtk_tooltips_set_tip (tooltips, widget, 
 			symbol->getHint(), symbol->getHint());
 }
@@ -444,10 +478,6 @@ void LWPiece::setBackgroundPixmap (LWPixmap *pixmap)
 {
    	backpixmap = pixmap;
 	updateImage();
-
-	if (pixmap != NULL)
-		if (LW_TYPE_PLAYGROUND != row->getBoard()->getType())
-			gtk_drag_source_set_icon_pixbuf (widget, pixmap->getPixbuf());
 }
 
 /*! \brief Aktalizacja obrazu zawartego na klocku
@@ -479,6 +509,27 @@ void LWPiece::updateImage ()
 		composite_image (image, forepixmap, backpixmap, size);
 	else
 		composite_image (image, backpixmap, forepixmap, size);
+	
+	if (LW_TYPE_WORLD == row->getBoard()->getType())
+		if (ifDNDWillMoveWizard()) {
+			gtk_drag_source_set (widget, GDK_BUTTON1_MASK,
+				target_table, n_targets, 
+	    		GDK_ACTION_MOVE);
+			gtk_drag_source_set_icon_pixbuf (widget, forepixmap->getPixbuf());
+			return;
+		} 
+		else
+		{
+			gint source_actions = GDK_ACTION_COPY | GDK_ACTION_MOVE;
+				
+			gtk_drag_source_set (widget, GDK_BUTTON1_MASK,
+				target_table, n_targets, 
+	    	(GdkDragAction) source_actions);
+		}
+	
+	if (backpixmap != NULL)
+		if (LW_TYPE_PLAYGROUND != row->getBoard()->getType())
+			gtk_drag_source_set_icon_pixbuf (widget, backpixmap->getPixbuf());
 }
 
 /*! \brief Włącza odwrócenie warstw
@@ -504,15 +555,21 @@ void LWPiece::clear ()
 {
 	forepixmap = NULL;
 	backpixmap = NULL;
-	symbol = NULL;
+
+	if (symbol != NULL)
+		if (TRUE == symbol->canClone()) {
+			delete symbol;
+			symbol = NULL;
+		}
 	
 	if (image != NULL) {
 		gtk_widget_destroy (image);
 		image = NULL;
 	}
 
-	if (LW_TYPE_PLAYGROUND != row->getBoard()->getType())
-		gtk_drag_source_set_icon_stock (widget, GTK_STOCK_DND);
+	if (LW_TYPE_PLAYGROUND != row->getBoard()->getType() &&
+		FALSE == row->isPieceDummy (this))
+			gtk_drag_source_set_icon_stock (widget, GTK_STOCK_DND);
 }
 
 /*! \brief Dostowuje zawartość klocka
@@ -526,10 +583,19 @@ void LWPiece::copy (LWPiece *piece)
 	
 	setForegroundPixmap(piece->forepixmap);
 	setBackgroundPixmap(piece->backpixmap);
-	
+		
 	if (piece->symbol != NULL) {
+		
+		if (symbol != NULL)
+			if (TRUE == symbol->canClone())
+				delete symbol;
+		
 		symbol = (TRUE == piece->symbol->canClone()) ? 
 			piece->symbol->clone() : piece->symbol;
+		
+		g_return_if_fail (symbol != NULL);
+		
+		symbol->onAttach (this);
 	
 		gtk_tooltips_set_tip (tooltips, widget, 
 								symbol->getHint(), symbol->getHint());
@@ -542,15 +608,16 @@ void LWPiece::copy (LWPiece *piece)
 	Kojarzy klocek z wierszem, inicjacja drag'n'drop (metoda prywatna)
 	\param row Wiersz z którym klocek zostanie skojarzony
 */
-void LWPiece::attach (LWRow *row)
+void LWPiece::attach (LWRow *a_row)
 {
 gint source_actions=0;
 gint dest_actions=0;
 	
-	g_return_if_fail (row != NULL);
-	g_return_if_fail (row->getBoard() != NULL);
+	g_return_if_fail (a_row != NULL);
+	g_return_if_fail (a_row->getBoard() != NULL);
+	g_return_if_fail (symbol == NULL);
 	
-	switch (row->getBoard()->getType ()) {
+	switch (a_row->getBoard()->getType ()) {
 		case LW_TYPE_ICONS: 
 			source_actions = GDK_ACTION_COPY;
 			dest_actions = 0;
@@ -562,14 +629,14 @@ gint dest_actions=0;
 			break;
 		
 		case LW_TYPE_WORLD:
-			source_actions = GDK_ACTION_COPY;
-			dest_actions = GDK_ACTION_COPY;
+			source_actions = GDK_ACTION_COPY | GDK_ACTION_MOVE;
+			dest_actions = GDK_ACTION_COPY | GDK_ACTION_MOVE;
 			break;
 		
 		case LW_TYPE_PROGRAM:
-			source_actions = GDK_ACTION_MOVE;
-			dest_actions = GDK_ACTION_COPY | GDK_ACTION_MOVE; 
-			break;
+			source_actions = GDK_ACTION_MOVE | GDK_ACTION_LINK;
+			dest_actions = GDK_ACTION_COPY | GDK_ACTION_MOVE | GDK_ACTION_LINK; 
+		break;
 		
 		case LW_TYPE_PLAYGROUND: 
 			source_actions = 0;
@@ -589,7 +656,7 @@ gint dest_actions=0;
 
 	if (source_actions != 0) {
 		gtk_drag_source_set (widget, GDK_BUTTON1_MASK,
-        	target_table, n_targets, 
+			target_table, n_targets, 
 	    	(GdkDragAction) source_actions);
 
 		g_signal_connect (G_OBJECT (widget), "drag_data_get",
@@ -597,17 +664,12 @@ gint dest_actions=0;
 	
 	}
 	
-	this->row = row;
+	row = a_row;
 }
 
-/*! \brief Czy jest symbolem złamania linii
-
-	Sprawdza czy ikona symolizuje złamanie linii
-	\return Rezultat testu
-*/
-gboolean LWPiece::isEnter ()
+gboolean LWPiece::ifDNDWillMoveWizard()
 {
-	return is_enter;
+	return ((inverted_grounds == FALSE || backpixmap == NULL) && forepixmap != NULL) ? TRUE : FALSE;
 }
 
 /*! \brief Pobranie kontrolki
