@@ -1,4 +1,4 @@
-/* (C) Marcin Kwadrans <quar@vitea.pl> */
+/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/pixmapset.h"
@@ -61,7 +61,7 @@ void LWPixmapSet::restoreFromXML (xmlNode *node)
 	Pobiera ikonę ze zbioru na podstawie jej nazwy
 	\name Nazwa ikony
 */
-LWPixmap *LWPixmapSet::getPixmap (gchar *name)
+LWPixmap *LWPixmapSet::getPixmap (const gchar *name)
 {
 	g_return_val_if_fail (name != NULL, NULL);
 	
