@@ -10,9 +10,9 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
-#include <stdio.h>
+#include <cstdio>
 #include "include/support.h"
 #include "project.h"
 #include "environment.h"
@@ -49,18 +49,19 @@ LWProject::~LWProject ()
 
 	Ładuje projekt z pliku
 	\param a_file_name Nazwa pliku z projektem
+	\return TRUE if success, otherwise FALSE.
 */	
-void LWProject::load (const gchar *a_file_name)
+gboolean LWProject::load (const gchar *a_file_name)
 {
-	/* przetwórz plik i pobierz DOM */
+	/* Parse the file and get the DOM */
     xmlDoc *doc = xmlParseFile(a_file_name);
 
-	g_return_if_fail (doc != NULL);
+	if (doc == NULL) return FALSE;
 
-    /* Pobierz węzeł korzenia */
+    /* Get root node */
     xmlNode *node = xmlDocGetRootElement(doc);
 
-	g_return_if_fail (!xmlStrcasecmp (node->name, (xmlChar *) "LittleWizardProject"));
+	g_return_val_if_fail (!xmlStrcasecmp (node->name, (xmlChar *) "LittleWizardProject"), FALSE);
 	
 	/* Version check */
 	xmlChar *version = xmlGetProp (node, (xmlChar *) "version");
@@ -69,7 +70,7 @@ void LWProject::load (const gchar *a_file_name)
 		sscanf ((char *) version, "%u.%u", &promajor, &prominor);
 		sscanf (VERSION, "%u.%u", &envmajor, &envminor);
 		xmlFree (version);
-		g_return_if_fail (promajor < envmajor || (promajor == envmajor && prominor <= envminor));
+		g_return_val_if_fail (promajor < envmajor || (promajor == envmajor && prominor <= envminor), FALSE);
 	}
 	
 #if 1
@@ -89,14 +90,17 @@ void LWProject::load (const gchar *a_file_name)
 	xmlFreeDoc (doc);
 	
 	setFileName (a_file_name);	
+	
+	return TRUE;
 }
 
 /*! \brief Zapisywanie projektu do pliku
 
 	Zapisuje projekt do pliku
 	\param a_file_name Nazwa pliku, pod którą ma być zapisany projekt
+	\return TRUE if success, otherwise FALSE.
 */	
-void LWProject::save (const gchar *a_file_name)
+gboolean LWProject::save (const gchar *a_file_name)
 {
     xmlDoc *doc = xmlNewDoc(BAD_CAST "1.0");
     xmlNode *node = xmlNewNode(NULL, BAD_CAST "LittleWizardProject");
@@ -113,11 +117,13 @@ void LWProject::save (const gchar *a_file_name)
 	world->storeToXML (node);
 	program->storeToXML (node);
 
-	xmlSaveFile (a_file_name, doc);
+	int r = xmlSaveFile (a_file_name, doc);
 	
 	xmlFreeDoc (doc);
 	
 	setFileName (a_file_name);
+	
+	return (r > -1) ? TRUE : FALSE;
 }
 
 /*! \brief Ustawia nazwę pliku
