@@ -11,10 +11,13 @@
  */
 
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/row.h"
+#include "include/wizard.h"
+
+static const GdkColor markcolor = {0, 0xc000, 0xc000, 0xc000};
 
 /*! \brief Inicjalizowanie wiersza
 
@@ -24,6 +27,8 @@
 */
 void LWRow::init (LWBoard *a_board)
 {
+	g_return_if_fail ( a_board != NULL );
+	
 	board = a_board;
 	
 	widget = gtk_hbox_new (FALSE, a_board->isGridEnabled() == TRUE ? 2 : 0);
@@ -31,7 +36,8 @@ void LWRow::init (LWBoard *a_board)
 	
 	if (LW_TYPE_PROGRAM == board->getType()) {
 		dummy_piece = new LWPiece (this);
-
+		gtk_drag_source_unset (dummy_piece->getWidget());
+			
 		gtk_box_pack_end (GTK_BOX (widget), dummy_piece->getWidget(), TRUE, TRUE, 0);
 	}
 }
@@ -42,7 +48,7 @@ void LWRow::init (LWBoard *a_board)
 	
 	\param board Plansza do której będzie należał wiersz 
 */
-LWRow::LWRow (LWBoard *a_board): list_piece(NULL), dummy_piece(NULL)
+LWRow::LWRow (LWBoard *a_board): list_piece(NULL), dummy_piece(NULL), remark_piece(NULL)
 {
 	init (a_board);
 }
@@ -54,7 +60,8 @@ LWRow::LWRow (LWBoard *a_board): list_piece(NULL), dummy_piece(NULL)
 	
 	\param board Plansza do której będzie należał wiersz 
 */
-LWRow::LWRow (const LWRow *row, LWBoard *a_board): list_piece(NULL), dummy_piece(NULL)
+LWRow::LWRow (const LWRow *row, LWBoard *a_board): list_piece(NULL),
+dummy_piece(NULL), remark_piece(NULL)
 {
 	init (a_board);
 	
@@ -71,6 +78,16 @@ LWRow::LWRow (const LWRow *row, LWBoard *a_board): list_piece(NULL), dummy_piece
 */
 LWRow::~LWRow ()
 {
+	LWWizard *wizard = board->getWizard();
+	
+	if (wizard != NULL)
+		if (wizard->getPiece()->getRow() == this) {
+			guint x = getPieceIndex(wizard->getPiece());
+			guint y = board->getRowIndex (this);
+			g_assert (y > 0);
+			wizard->setPiece (board->getRowNth (y-1)->getPieceNth (x));			
+		}
+		
 	clear();
 	
 	if (NULL != dummy_piece)
@@ -142,6 +159,9 @@ void LWRow::addPiece (LWPiece *piece)
 	
 	gtk_box_pack_start (GTK_BOX (widget), piece->getWidget(), FALSE, FALSE, 0);
 	list_piece = g_slist_append (list_piece, (gpointer) piece);
+		
+	if (remark_piece != NULL)
+		gtk_widget_modify_bg (piece->getWidget(), GTK_STATE_NORMAL, &markcolor);
 }
 
 /*! \brief Dodanie klocka do wiersza przed innym klockiem
@@ -171,6 +191,10 @@ gint a=0;
 		board->addRow (row);
 		piece->row = row; 
 		row->addPiece (piece);
+		if (remark_piece == piece) {
+			row->setAsRemark (piece);
+			remark_piece = NULL;
+		}
 		return;
 	}
 
@@ -201,8 +225,22 @@ gint a=0;
 	
 	if (dummy_piece != NULL) a = 1;	
 
-	gtk_box_reorder_child (GTK_BOX (widget), piece->getWidget(), 
-		g_slist_index (list_piece, (gpointer) piece)+a);
+	gint n = g_slist_index (list_piece, (gpointer) piece);
+	
+	gtk_box_reorder_child (GTK_BOX (widget), piece->getWidget(), n+a);
+
+	if (remark_piece == piece)
+		for (GSList *l = g_slist_find (list_piece, (gpointer) piece); l != NULL; l = l->next) {
+			LWPiece *piece = (LWPiece *) l->data;
+			gtk_widget_modify_bg (piece->getWidget(), GTK_STATE_NORMAL, &markcolor);
+		}	
+	else
+	if (remark_piece != NULL) {
+		gint n2 = g_slist_index (list_piece, (gpointer) remark_piece);
+		
+		if (n2 >= 0 && n > n2)
+			gtk_widget_modify_bg (piece->getWidget(), GTK_STATE_NORMAL, &markcolor);
+	}
 }
 
 /*! \brief Usuwanie klocka
@@ -218,32 +256,15 @@ void LWRow::removePiece (LWPiece *piece)
 	g_return_if_fail (piece->row == this);
 
 	if (NULL == piece->row->getPieceNth (1)) {
-		piece->row->board->removeRow (piece->row); return;
-		
-/*
-		LWRow *del_row = NULL;
-		gint n = piece->row->board->getRowIndex (piece->row);
-		
-		if (n == 0) 
-			del_row = piece->row;
-		else	
-		if (NULL == piece->row->board->getRowNth(n-1)->getPieceNth(0))
-			del_row = piece->row;
-		else
-		if (NULL == piece->row->board->getRowNth(n+1))
-			del_row = piece->row;
-		else
-		if (NULL == piece->row->board->getRowNth(n+1)->getPieceNth(0))
-			del_row = piece->row;
-		
-		if (del_row != NULL) {
-			piece->row->board->removeRow (del_row); return;				
-		}
-*/
+		piece->row->board->removeRow (piece->row); 
+		return;
 	}
-	
-	list_piece = g_slist_remove (list_piece, (gpointer) piece);
+
+	if (remark_piece == piece)
+		clearRemark();
+		
 	delete piece;
+	list_piece = g_slist_remove (list_piece, (gpointer) piece);
 }
 
 /*! \brief Dzieli wiersz
@@ -267,6 +288,10 @@ void LWRow::splitBefore (LWPiece *piece)
 		
 		LWPiece *new_piece = new LWPiece (orig_piece, new_row);
 		new_row->addPiece (new_piece);
+
+		if (orig_piece == remark_piece) 
+			new_row->setAsRemark (new_piece);
+		
 		removePiece (orig_piece);
 	}
 }
@@ -307,7 +332,18 @@ LWPiece *LWRow::getPieceNth (guint n)
 */
 GSList *LWRow::getPieceList ()
 {
-	return g_slist_copy (list_piece);	
+	if (remark_piece == NULL)
+		return g_slist_copy (list_piece);
+	else 
+	{ 
+		GSList *rem_l = g_slist_find (list_piece, (gpointer) remark_piece);
+		GSList *copy_l = NULL;
+		
+		for (GSList *l = list_piece; l != rem_l; l = l->next)
+			copy_l = g_slist_append (copy_l, l->data);
+		
+		return copy_l;
+	}
 }
 
 /*! \brief Ustawienie rozmiaru wiersza 
@@ -323,8 +359,8 @@ GSList *l;
 	/* Zmniejsz liczbe elementow jeśli potrzeba */
 	while (NULL != (l = g_slist_nth (list_piece, length))) {
 		LWPiece *piece = (LWPiece *) l->data;
-		g_slist_delete_link (list_piece, l);
-		delete piece;
+		delete piece;	
+		list_piece = g_slist_delete_link (list_piece, l);	
 	}
 
 	/* Zwiększ liczbę elementów jeśli potrzeba */
@@ -371,25 +407,52 @@ void LWRow::clear ()
 	list_piece = NULL;	
 }
 
-/*! \brief Pobieranie kontrolki
- 
-	Pobiera kontrolkę (ang. widget) zawierającą wiersz
+void LWRow::setAsRemark(LWPiece *a_piece)
+{
+	g_return_if_fail (a_piece != NULL);
+	g_return_if_fail (a_piece->getRow() == this);
+	
+	if (remark_piece != NULL) {
+		removePiece(remark_piece);
+	}
 
-	\return Zwrócona kontrolka
+	remark_piece = a_piece;
+	
+	for (GSList *l = g_slist_find (list_piece, (gpointer) a_piece); l != NULL; l = l->next) {
+		LWPiece *piece = (LWPiece *) l->data;
+		gtk_widget_modify_bg (piece->getWidget(), GTK_STATE_NORMAL, &markcolor);
+	}
+}
+
+void LWRow::clearRemark()
+{
+	g_return_if_fail (remark_piece != NULL);
+	
+	for (GSList *l = g_slist_find (list_piece, (gpointer) remark_piece); l != NULL; l = l->next) {
+		LWPiece *piece = (LWPiece *) l->data;
+		gtk_widget_modify_bg (piece->getWidget(), GTK_STATE_NORMAL, NULL);
+	}
+		
+	remark_piece = NULL;
+}
+
+/*! \brief Get a widget
+ 
+	It gets a widget of the row
+
+	\return Returned widget
 */
 GtkWidget *LWRow::getWidget ()
 {
 	return widget;
 }
 
-/*! \brief Sprawdzanie czy element jest dodatkowy
+/*! \brief Check if this a piece is additional dummy piece
 
-	Sprawdza czy elemet jest dodadkowym elementem, 
-	Metoda przeznaczona wyłącznie do obsługi mechanizmu 
-	Przeciągnij i Upuść.
+	It checks if that is additional dummy piece (drag&n&drop helper piece
+	at the end of row). Method should be used only be drag&n&drop subsystem.
 	
-	\return Rezultat testu. TRUE jeśli wiersz jest dodatkowy,
-	w przeciwnym wypdaku FALSE
+	\return Result of a test. TRUE if piece is additional dummy piece, in other case FALSE.
 */
 gboolean LWRow::isPieceDummy (LWPiece *piece)
 {
