@@ -10,22 +10,46 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
-#include <stdlib.h>
+#include <cstdlib>
+#include <cstring>
 #include "include/support.h"
 #include "include/variable.h"
 #include "include/environment.h"
 
-#define MAKE_TWIN(v) const LWValue *twin = (FALSE == v->isSpecial()) ? v : v->get();
-#define FREE_TWIN if (TRUE == isSpecial()) delete twin;
+#define MAKE_TWIN(v) LWValue *twin = (FALSE == (v)->isSpecial()) ? v : (v)->get(); \
+					 const gboolean needRelease = (TRUE == v->isSpecial());
+
+#define FREE_TWIN if (needRelease == TRUE) delete twin;
+
+#define MAKE_TWIN2(v) LWValue *twin2 = (FALSE == (v)->isSpecial()) ? v : (v)->get(); \
+					  const gboolean needRelease2 = (TRUE == (v)->isSpecial());
+
+#define FREE_TWINS  if (needRelease == TRUE) delete twin; \
+					if (needRelease2 == TRUE) delete twin2;
 
 static int pixmapToInt (LWPixmap *pixmap)
+{
+	g_return_val_if_fail (pixmap != NULL, 0);
+
+	gchar *s = pixmap->getName ();
+	
+	if (!strcmp(s, "true"))
+		return 1;
+	
+	if (!strcmp (s, "false"))
+		return 0;
+	
+	return atoi (s);
+}
+
+static int _isInt (LWPixmap *pixmap)
 {
 	g_return_val_if_fail (pixmap != NULL, 0);
 	
 	gchar *s = pixmap->getName ();
-	return atoi (s);
+	return (s[0] >= '0' && s[0] <= '9') ? TRUE : FALSE;
 }
 
 static LWPixmap *intToPixmap (gint n)
@@ -164,7 +188,7 @@ void LWValue::append (LWPixmap *pixmap)
 void LWValue::concat (LWValue *value)
 {
 	g_return_if_fail (value != NULL);
-	g_return_if_fail (FALSE == value->isSpecial());
+	MAKE_TWIN (value)
 	
 	if (TRUE == canBeIndexed ())
 		convertToList();
@@ -172,11 +196,11 @@ void LWValue::concat (LWValue *value)
 	if (is_list == FALSE) 
 		return;
 
-	if (value->is_list == FALSE)
+	if (twin->is_list == FALSE)
 		list = g_slist_append (list, (TRUE == isVariable()) ?
-			new LWVariable(pixmap) : new LWValue(pixmap));
-		
-	for (GSList *l= value->list; l != NULL; l = l->next) {
+			new LWVariable(twin->pixmap) : new LWValue(twin->pixmap));
+	else	
+	for (GSList *l= twin->list; l != NULL; l = l->next) {
 		LWValue *v = (LWValue *) l->data;
 		
 		if (TRUE == isVariable())
@@ -188,6 +212,8 @@ void LWValue::concat (LWValue *value)
 				g_slist_append (list, new LWVariable (v->pixmap)) :
 					g_slist_append (list, new LWVariable (v));
 	}
+		
+	FREE_TWIN
 }
 
 /*! \brief Interpretacja jako liczba
@@ -200,13 +226,7 @@ gint LWValue::toInt ()
 	MAKE_TWIN(this)
 	
 	if (twin->is_list == FALSE)
-		if (twin->pixmap != NULL) {
-			FREE_TWIN
-			return pixmapToInt (twin->pixmap);
-		} else {
-			FREE_TWIN
-			return 0;
-		}
+		return (twin->pixmap != NULL) ? pixmapToInt (twin->pixmap) : 0;
 			
 	gboolean isminus = FALSE;
 	gint ivalue = 0;
@@ -215,13 +235,14 @@ gint LWValue::toInt ()
 	for (l = twin->list; l != NULL; l = l->next) {
 		LWValue *v = (LWValue *) l->data;
 		if (v->is_list == TRUE) return 0;
+		if (v->pixmap == NULL) continue;
 		if (getMinusSign () == v->pixmap) isminus = TRUE; 
 		else if (pixmapToInt( (LWPixmap *) v->pixmap) > 0) break;
 		}
 		
 	for (; l != NULL; l = l->next) {
 		LWValue *v = (LWValue *) l->data;
-		if (v->is_list == TRUE) break;
+		if (v->is_list == TRUE || v->pixmap == NULL || FALSE == _isInt(v->pixmap)) break;
 		ivalue *= 10; 
 		ivalue += pixmapToInt( (LWPixmap *) v->pixmap);
 	}
@@ -261,6 +282,26 @@ LWValue *LWValue::getIndex (guint n)
 	return (value != NULL) ? new LWValue (value) : new LWValue();
 }
 
+void LWValue::deleteIndex (guint n)
+{
+	g_return_if_fail (n > 0);
+	g_return_if_fail (TRUE == canBeIndexed());
+	g_return_if_fail (FALSE == isSpecial());
+		
+	if (is_list == FALSE) {
+		convertToList ();
+	}
+		
+	GSList *l = g_slist_nth (list, n-1);
+	
+	if (l != NULL) {
+		if (l->data)
+			delete (LWValue *) l->data;
+		
+		list = g_slist_delete_link (list, l);
+	}
+}
+
 /*! \brief Pobiera listę ikon
 
 	Pobiera listę ikon znajdującą się w wartości
@@ -270,8 +311,9 @@ GSList *LWValue::getListPixmap ()
 {
 	MAKE_TWIN(this)
 	
-	if (twin->is_list == FALSE) 
+	if (twin->is_list == FALSE) {
 		return g_slist_append (NULL, twin->pixmap);
+	}
 	
 	GSList *list_pixmap=NULL;
 	
@@ -314,10 +356,10 @@ LWPixmap *p=NULL;
 	return p;
 }
 
-/*! \brief Ustawia wartość listy
+/*! \brief Set the value 
 
-	Ustawia wartość na podstawie innej wartości
-	\param value Wartość na podstawie, której ma być dokonane podstawienie
+	Set the value basing on another value
+	\param value The value that should be used for assigment
 */
 void LWValue::set (LWValue *value)
 {
@@ -357,21 +399,20 @@ void LWValue::set (LWValue *value)
 	FREE_TWIN
 }
 
-/*! \brief Pobranie kopi wartości
+/*! \brief Get the copy of the value
 
-	Pobiera kopię wartości
-	\return Pobrana wartość
+	It gets the copy of the value
+	\return Copy of a value
 */
 LWValue *LWValue::get()
 {
 	return new LWValue(this);
 }
 
-/*! \brief Zliczanie elementów w liści
+/*! \brief Counting elements in a list
 	
-	Zlicza ilość elementów w liście, jeśli wartość jest piksmapą
-	zwracane jest 1.
-	\return Ilość elementów w liście
+	Counts elements in a list, if value is a pixmap it returns 1.
+	\return Number of elements in a list
 */
 guint LWValue::count ()
 {
@@ -384,23 +425,203 @@ guint LWValue::count ()
 	return count;
 }
 
-/*! \brief Czy wartość stanowi zmienną
+/*! \brief Checking if value is a integer
+	
+	Checks if value is a integer (string with only digits and optional minus sign at first position).
+	\return Result of of test.
+*/
+gboolean LWValue::isInt ()
+{
+	MAKE_TWIN(this)
+	
+	if (twin->is_list == FALSE) {
+		gboolean r = (twin->pixmap != NULL)	? _isInt (twin->pixmap) : FALSE;
+		FREE_TWIN
+		return r;
+	}
+			
+	GSList *l = twin->list;
+		
+	if (l == NULL) {
+		FREE_TWIN
+		return FALSE;
+	}
+				
+	LWValue *v = (LWValue *) l->data;
+	
+	if (v->is_list == FALSE)	
+		if (getMinusSign () == v->pixmap)
+			l = l->next;
+		
+	for (; l != NULL; l = l->next) {
+		v = (LWValue *) l->data;
+		
+		if (v->is_list == TRUE || v->pixmap == NULL || _isInt((LWPixmap *) v->pixmap) == FALSE) {
+			FREE_TWIN	
+			return FALSE;
+		}
+	}
 
-	Czy wartość stanowi zmienną
-	\return Nie przeciążona metoda zawsze zwraca fałsz
+	FREE_TWIN
+	
+	return TRUE;
+}
+
+/*! \brief Checking if the value fits in the integer range
+	
+	Checks if the value can be converted to "gint" without an overflow.
+	\return True if can fit in integer range
+*/
+gboolean LWValue::checkRange ()
+{
+	MAKE_TWIN(this)
+	
+	if (twin->is_list == FALSE) {
+		FREE_TWIN 
+		return TRUE;
+	}
+
+	GSList *l = twin->list;
+
+	LWValue *v = (LWValue *) l->data;
+	
+	if (v->is_list == TRUE) {
+		FREE_TWIN 
+		return TRUE;
+	}
+
+	guint limit;
+
+	if (getMinusSign () == v->pixmap) {
+		gint min = G_MININT;
+		limit = (guint) -min;
+		l = l->next;
+	} else {
+		limit = (guint) G_MAXINT;
+	}
+	
+	for (; l != NULL && limit > 0; l = l->next, limit /= 10) {
+		v = (LWValue *) l->data;
+				
+		if (v->is_list == TRUE || v->pixmap == NULL || _isInt((LWPixmap *) v->pixmap) == FALSE) {
+			FREE_TWIN	
+			return TRUE;
+		}
+			
+		if (limit < 10 && limit < (guint) pixmapToInt((LWPixmap *) v->pixmap)) {
+			FREE_TWIN	
+			return FALSE;
+		}
+	}
+
+	FREE_TWIN
+
+	return (limit > 0) ? TRUE : FALSE;
+}
+
+/*! \brief Comparation of the values
+	
+	The smart way of comparing of the values. It can be used to numerical or
+	lexigraphical sorting depends on the contet of values.
+	It can be used for comparing single values or whole arrays.
+
+	\param value The compared value
+	\return -1, 0 or 1 depends on the result of comparation.
+*/
+gint LWValue::compare (LWValue *value)
+{
+	if (this == value) return 0;
+	
+	MAKE_TWIN(this)
+	MAKE_TWIN2(value)
+	
+	if (twin->isInt() == TRUE && twin2->isInt() == TRUE) {
+		gint i1 = twin->toInt();
+		gint i2 = twin2->toInt();
+		FREE_TWINS
+		return (i1 == i2) ? 0 : ((i1 < i2) ? -1 : 1);
+	}
+	
+	if (FALSE == twin->is_list && FALSE == twin2->is_list) {
+		gchar *s1 = (twin->pixmap != NULL) ? twin->pixmap->getName() : (gchar *) " ";
+		gchar *s2 = (twin2->pixmap != NULL) ? twin2->pixmap->getName() : (gchar *) " ";
+		gint r = strcmp (s1, s2);
+		FREE_TWINS
+		return r;
+	}
+	
+	if (TRUE == twin->is_list && FALSE == twin2->is_list) {
+		gint r;
+		
+		if (twin->list != NULL) {
+			LWValue *v = twin->getIndex(1);
+			r = v->compare(twin2);
+			if (r == 0) r = 1;
+			if (!v->isVariable()) delete v;
+		} else 
+			r = -1;
+			
+		FREE_TWINS
+		return r;
+	}
+	
+	if (FALSE == twin->is_list && TRUE == twin2->is_list) {
+		gint r;
+	
+		if (twin2->list != NULL) {
+			LWValue *v = twin2->getIndex(1);
+			r = twin->compare(v);
+			if (r == 0) r = -1;
+			if (!v->isVariable()) delete v;
+		} else r = 1;
+					
+		FREE_TWINS
+		return r;
+	}
+		
+	GSList *l = twin->list;
+	GSList *l2 = twin2->list;	
+
+	for (; l != NULL && l2 != NULL; l = l->next, l2 = l2->next) {
+		LWValue *t1 = (LWValue *) l->data;
+		LWValue *t2 = (LWValue *) l2->data;
+		
+		guint r = t1->compare (t2);
+		
+		if (r == 0) continue;
+			
+		FREE_TWINS
+		
+		return r;
+	}
+	
+	FREE_TWINS
+	
+	return (l == NULL && l2 == NULL) ? 0 : ((l != NULL) ? 1 : -1);
+}
+
+/*! \brief Is it a variable
+
+	Is it a variable ?
+	\return Not overwritten method returns always FALSE
 */
 gboolean LWValue::isVariable ()
 {
 	return FALSE;
 }
 
-/*! \brief Czy wartość specjalna
+/*! \brief Is it a special value
 	
-	Czy wartość jest wartością specjalną, zwraca FAŁSZ.
-	Metoda przeciążana w implementacji wartości specjalnej.
+	Is it a special value?
+	Method overwritten in implementation of special values (f.i world variable)
+	The "special" means that the content is not stored directly in a value,
+	but the value class is only some kind of interface that behaves like an
+	value, but the real content is stored somewhere else. For special value 
+	at least "set" and "get" methods should work correctly, other methods
+	internally should use copy generated by "get" method, 
+	which is no longer special value.
 
-	\return PRAWDA jeśli wartość jest specjalna, w przeciwnym
-	razie FAŁSZ
+	\return Not overwritten method returns always FALSE
 */
 gboolean LWValue::isSpecial ()
 {
