@@ -10,16 +10,16 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/wizard.h"
 #include "include/environment.h"
 
-/*! \brief Konstruktor czarodzieja
+/*! \brief Constructor of a wizard
 
-	Tworzy czarodzieja, umiejscawiając go na klocku
-	\param a_piece Klocek na którym ma być umieszczony czarodziej
+	It creates a wizard and place new wizard on a piece
+	\param a_piece Piece where new wizard should be placed
 */	
 LWWizard::LWWizard (LWPiece *a_piece):
 visibility (TRUE), sleep_time(1.4), inverted_grounds(TRUE)
@@ -28,6 +28,37 @@ visibility (TRUE), sleep_time(1.4), inverted_grounds(TRUE)
 	direction = LW_DIRECTION_EAST;
 }
 
+/*! \brief Copy constructor of a wizard
+
+	It creates a wizard and place new wizard on a new board.
+	Piece where new wizard will be placed has the same position (x,y)
+	on board as copied wizard.
+
+	\param board Board where new wizard should be placed
+*/	
+LWWizard::LWWizard (const LWWizard *wizard, LWBoard *board):
+visibility (wizard->visibility), sleep_time(wizard->sleep_time), inverted_grounds(wizard->inverted_grounds)
+{
+	direction_pixmaps[LW_DIRECTION_EAST] = wizard->direction_pixmaps[LW_DIRECTION_EAST];
+	direction_pixmaps[LW_DIRECTION_SOUTH] = wizard->direction_pixmaps[LW_DIRECTION_SOUTH];
+	direction_pixmaps[LW_DIRECTION_WEST] = wizard->direction_pixmaps[LW_DIRECTION_WEST];
+	direction_pixmaps[LW_DIRECTION_NORTH] = wizard->direction_pixmaps[LW_DIRECTION_NORTH];
+
+	LWPiece *a_piece = wizard->piece;
+	guint x = a_piece->getRow()->getPieceIndex(a_piece);
+	guint y = a_piece->getRow()->getBoard()->getRowIndex(a_piece->getRow());
+	
+	LWRow *new_row = board->getRowNth (y);
+	g_assert (new_row != NULL);
+	
+	piece = new_row->getPieceNth(x);
+	g_assert (piece != NULL);
+	
+	direction = wizard->direction;
+	
+	if (visibility == TRUE) show ();
+}
+
 /*! \brief Destruktor
 
 	Niszczy czarodzieja
@@ -104,7 +135,12 @@ LWDirection LWWizard::getDirection ()
 void LWWizard::setSpeed (gint speed)
 {
 	sleep_time = (9.0 - (double) CLAMP(speed,0,9) ) * 0.2;
-	
+}
+
+
+guint LWWizard::getPauseTime ()
+{
+	return (guint) (sleep_time * 1000);
 }
 
 /*! \brief Obracanie czarodzieja
@@ -170,40 +206,6 @@ void LWWizard::show ()
 	visibility = TRUE;
 }
 
-static gboolean timeoutCb (gboolean *finished)
-{
-	*finished = TRUE;
-	return FALSE;
-}
-
-/*! \brief Pauzuje czrodzieja
-
-	Odstęp czasowy między ruchami
-*/
-void LWWizard::pause ()
-{
-	gboolean finished=FALSE;
-	
-	if (sleep_time >  0) {
-		/* It's not very precise way of realising waiting,
-		   but it doesn't consume whole processor time,
-		   and serve events while waiting */
-		
-		g_timeout_add ((guint) (sleep_time * 1000.0), 
-			(GSourceFunc) timeoutCb, (gpointer) &finished);
-	
-		do {
-  			gtk_main_iteration ();
- 		} while (finished == FALSE);
-
-	} else {
-		/* Serve pending events and exit */
-		while (TRUE == gtk_events_pending ())
-			gtk_main_iteration ();
-
-	}
-}
-
 /*! \brief Pobranie N-tego klocka stojącego przed czarodziejem
 
 	Pobiera N-ty klocek stojący przed czarodziejem. 
@@ -310,36 +312,6 @@ LWPiece *gotpiece;
 	return (gotpiece != NULL) ? TRUE : FALSE;
 }
 
-/*! \brief Rusz się
-
-	Rusza czarodzieja o zadaną ilość kroków.
-	\param n Zadana ilość kroków, jeśli wartość ujemna porusza czarodzieja do tyłu
-*/
-void LWWizard::go (gint n, gboolean wait)
-{
-	if (n > 0)
-		for (gint i = 0; i < n; i++) {
-			
-			if (wait == TRUE)
-				pause();
-
-			if (FALSE == stepForward())
-				return;
-				
-		}
-		
-	if (n < 0)
-		for (gint i = 0; i < - n; i++) {
-
-			if (wait == TRUE)
-				pause();
-			
-			if (FALSE == stepBack())
-				return;
-			
-		}
-}
-
 /*! \brief Tworzenie obiektu przed czarodziejem
 
 	Tworzy obiekt przed czarodziejem
@@ -363,12 +335,15 @@ gboolean LWWizard::createOne (LWPixmap *pixmap, gint n)
 	Tworzy wartość przed czarodziejem
 	\param pixmap Wartość do stworzenia
 */
-void LWWizard::create (LWValue *value, gboolean wait)
+void LWWizard::create (LWValue *value)
 {
-	if (wait == TRUE)
-		pause();
+	g_return_if_fail (value != NULL);
 
 	GSList *list = value->getListPixmap();
+	
+	if (direction == LW_DIRECTION_WEST || direction == LW_DIRECTION_NORTH)	
+		list = g_slist_reverse (list);
+		
 	gint n = 1;
 	
 	for (GSList *l = list; l != NULL; l = l->next)
@@ -386,7 +361,11 @@ void LWWizard::create (LWValue *value, gboolean wait)
 		show();
 		
 	g_slist_free (list);
-	
+}
+
+gboolean LWWizard::isCreatingPossible ()
+{
+	return (NULL != getPieceNth (1)) ? TRUE : FALSE;
 }
 
 void LWWizard::setPiece (LWPiece *a_piece)
@@ -419,3 +398,8 @@ void LWWizard::enableInvertedGrounds (gboolean inverted)
 
 	piece->enableInvertedGrounds (inverted);	
 }
+
+LWPixmap *LWWizard::getDirectionPixmap (LWDirection a_direction)
+{
+	return direction_pixmaps[a_direction];
+}
