@@ -10,11 +10,13 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/environment.h"
 
+extern gboolean enable_debug;
+
 #define DISALLOW_RECURSIVE \
 {\
 	static gboolean _recursive=FALSE;\
@@ -225,7 +227,7 @@ void on_execute ()
 	LWProgram *program = new LWProgram();
 	program->setWorld(LWEnvironment::getProject()->getWorld());
 	
-	if (TRUE == program->parse(LWEnvironment::getProject()->getProgram()))
+	if (TRUE == program->parse(LWEnvironment::getProject()->getProgram(), enable_debug))
 		program->execute();
 }
 
