@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/environment.h"
@@ -105,7 +105,7 @@ void create_interface ()
 	gtk_widget_show (miprogram);
 	gtk_container_add (GTK_CONTAINER (menuitem5_menu), miprogram);
 
-	GtkWidget *miboth = gtk_radio_menu_item_new_with_mnemonic (group1, _("Mixed mode"));
+	GtkWidget *miboth = gtk_radio_menu_item_new_with_mnemonic (group1, _("Dual mode"));
 	gtk_widget_show (miboth);
 	gtk_container_add (GTK_CONTAINER (menuitem5_menu), miboth);
 
