@@ -10,7 +10,7 @@
  *  GNU General Public License for more details.
  */
 
- /* (C) Marcin Kwadrans <quar@vitea.pl> */
+ /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */
 
 #include "include/support.h"
 #include "include/environment.h"
@@ -19,11 +19,13 @@
 #include "icon48x48.xpm"
 #include "icon64x64.xpm"
 
-#include <string.h>
+#include <cstring>
 
 extern void create_interface ();
 extern void set_title (gchar *name);
+extern GData *get_symbols ();
 
+gboolean enable_debug = FALSE;
 
 int
 main (int argc, char *argv[])
@@ -43,7 +45,7 @@ main (int argc, char *argv[])
 
 	gtk_set_locale ();
 	
-	if (argc > 1)
+	if (argc > 1) {
 		if (!strcmp ("--help", argv[1])) {
 			char *prgname = g_path_get_basename(argv[0]);
 
@@ -56,9 +58,11 @@ main (int argc, char *argv[])
 			g_free (prgname);
 			return 0;
 			
-		} else if (!strcmp ("--version", argv[1])) {
+		} 
+		
+		if (!strcmp ("--version", argv[1])) {
 			g_print ("Little Wizard %s\n",VERSION);
-			g_print ("(C) Marcin Kwadrans <quar@vitea.pl>\n"\
+			g_print ("(C) Marcin Kwadrans <quarter@users.sourceforge.net>\n"\
 					 "This program is distributed in the hope that it will be useful,\n"\
 					 "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"\
 					 "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"\
@@ -66,9 +70,10 @@ main (int argc, char *argv[])
 			
 			return 0;
 		}
+	}
 
 	gtk_init (&argc, &argv);
-
+	
 	GList *icon_list=NULL;
 	icon_list = g_list_append(icon_list,
 		  (gpointer) gdk_pixbuf_new_from_xpm_data((const char**) icon32x32));
@@ -80,15 +85,25 @@ main (int argc, char *argv[])
 	g_list_foreach (icon_list, (GFunc) g_object_unref, NULL);
 	g_list_free (icon_list);
 	
-	LWEnvironment::init();
+	GData *symbols = get_symbols();
+	LWEnvironment::init(symbols);
 	LWProject *project = new LWProject();
 	LWEnvironment::setProject (project);
 
 	create_interface();
 
 	if (argc > 1) {
-		project->load (argv[1]);
-		set_title (argv[1]);
+		if (!strcmp ("--debug-tree", argv[1])) {
+			enable_debug = TRUE;
+	
+			if (argc > 2) {
+				project->load (argv[2]);
+				set_title (argv[2]);
+			}
+		} else {
+			project->load (argv[1]);
+			set_title (argv[1]);
+		}
 	}
 
 	gtk_main ();
